# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

VOLUME_SET_SPACE_METADATA = Metadata(
    id="cc06a5ed74f7b2995a9e56b76a45660865d0ab11.boutiques",
    name="volume-set-space",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


@dataclasses.dataclass
class VolumeSetSpacePlumb:
    """
    set via axis order and spacing/offset.
    """
    axis_order: str
    """a string like 'XYZ' that specifies which index is along which spatial
    dimension"""
    x_spacing: float
    """change in x-coordinate from incrementing the relevant index"""
    y_spacing: float
    """change in y-coordinate from incrementing the relevant index"""
    z_spacing: float
    """change in z-coordinate from incrementing the relevant index"""
    x_offset: float
    """the x-coordinate of the first voxel"""
    y_offset: float
    """the y-coordinate of the first voxel"""
    z_offset: float
    """the z-coordinate of the first voxel"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-plumb")
        cargs.append(self.axis_order)
        cargs.append(str(self.x_spacing))
        cargs.append(str(self.y_spacing))
        cargs.append(str(self.z_spacing))
        cargs.append(str(self.x_offset))
        cargs.append(str(self.y_offset))
        cargs.append(str(self.z_offset))
        return cargs


@dataclasses.dataclass
class VolumeSetSpaceSform:
    """
    set via a nifti sform.
    """
    xi_spacing: float
    """increase in x coordinate from incrementing the i index"""
    xj_spacing: float
    """increase in x coordinate from incrementing the j index"""
    xk_spacing: float
    """increase in x coordinate from incrementing the k index"""
    x_offset: float
    """x coordinate of first voxel"""
    yi_spacing: float
    """increase in y coordinate from incrementing the i index"""
    yj_spacing: float
    """increase in y coordinate from incrementing the j index"""
    yk_spacing: float
    """increase in y coordinate from incrementing the k index"""
    y_offset: float
    """y coordinate of first voxel"""
    zi_spacing: float
    """increase in z coordinate from incrementing the i index"""
    zj_spacing: float
    """increase in z coordinate from incrementing the j index"""
    zk_spacing: float
    """increase in z coordinate from incrementing the k index"""
    z_offset: float
    """z coordinate of first voxel"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-sform")
        cargs.append(str(self.xi_spacing))
        cargs.append(str(self.xj_spacing))
        cargs.append(str(self.xk_spacing))
        cargs.append(str(self.x_offset))
        cargs.append(str(self.yi_spacing))
        cargs.append(str(self.yj_spacing))
        cargs.append(str(self.yk_spacing))
        cargs.append(str(self.y_offset))
        cargs.append(str(self.zi_spacing))
        cargs.append(str(self.zj_spacing))
        cargs.append(str(self.zk_spacing))
        cargs.append(str(self.z_offset))
        return cargs


@dataclasses.dataclass
class VolumeSetSpaceFile:
    """
    copy spacing info from volume file with matching dimensions.
    """
    volume_ref: str
    """volume file to use for reference space"""
    opt_ignore_dims: bool = False
    """copy the spacing info even if the dimensions don't match"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-file")
        cargs.append(self.volume_ref)
        if self.opt_ignore_dims:
            cargs.append("-ignore-dims")
        return cargs


class VolumeSetSpaceOutputs(typing.NamedTuple):
    """
    Output object returned when calling `volume_set_space(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def volume_set_space(
    volume_in: InputPathType,
    volume_out: str,
    plumb: VolumeSetSpacePlumb | None = None,
    sform: VolumeSetSpaceSform | None = None,
    file: VolumeSetSpaceFile | None = None,
    runner: Runner | None = None,
) -> VolumeSetSpaceOutputs:
    """
    Change volume space information.
    
    Writes a copy of the volume file, with the spacing information changed as
    specified. No reordering of the voxel data occurs, see -volume-reorient to
    change the volume indexing order and reorder the voxels to match. Exactly
    one of -plumb, -sform, or -file must be specified.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        volume_in: the input volume.
        volume_out: output - the output volume.
        plumb: set via axis order and spacing/offset.
        sform: set via a nifti sform.
        file: copy spacing info from volume file with matching dimensions.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VolumeSetSpaceOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(VOLUME_SET_SPACE_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-volume-set-space")
    cargs.append(execution.input_file(volume_in))
    cargs.append(volume_out)
    if plumb is not None:
        cargs.extend(plumb.run(execution))
    if sform is not None:
        cargs.extend(sform.run(execution))
    if file is not None:
        cargs.extend(file.run(execution))
    ret = VolumeSetSpaceOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VOLUME_SET_SPACE_METADATA",
    "VolumeSetSpaceFile",
    "VolumeSetSpaceOutputs",
    "VolumeSetSpacePlumb",
    "VolumeSetSpaceSform",
    "volume_set_space",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_VALIDATE_SKULL_STRIPPED_METADATA = Metadata(
    id="2bdfa9e2cc73998aa283c518ac64ca8fd5b27024.boutiques",
    name="mri_validate_skull_stripped",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriValidateSkullStrippedOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_validate_skull_stripped(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mri_validate_skull_stripped(
    mri_reference: InputPathType,
    mri_test: InputPathType,
    weight: float,
    runner: Runner | None = None,
) -> MriValidateSkullStrippedOutputs:
    """
    Tool to validate skull stripped MRI images.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        mri_reference: Reference MRI image to compare against.
        mri_test: Test MRI image that has undergone skull stripping.
        weight: Weight parameter, should be greater than 1.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriValidateSkullStrippedOutputs`).
    """
    if not (1.01 <= weight): 
        raise ValueError(f"'weight' must be greater than 1.01 <= x but was {weight}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_VALIDATE_SKULL_STRIPPED_METADATA)
    cargs = []
    cargs.append("tntester")
    cargs.append(execution.input_file(mri_reference))
    cargs.append(execution.input_file(mri_test))
    cargs.append(str(weight))
    ret = MriValidateSkullStrippedOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_VALIDATE_SKULL_STRIPPED_METADATA",
    "MriValidateSkullStrippedOutputs",
    "mri_validate_skull_stripped",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_FIELDSIGN_METADATA = Metadata(
    id="ab824af01a699004ad68775dafe2a065f72a9634.boutiques",
    name="mri_fieldsign",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriFieldsignOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_fieldsign(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mri_fieldsign(
    fieldsign_file: str,
    eccen_values: list[float],
    polar_values: list[float],
    subject: str,
    hemisphere: str,
    patch_file: str | None = None,
    occip_flag: bool = False,
    sphere_flag: bool = False,
    fwhm: float | None = None,
    nsmooth: float | None = None,
    reverse_flag: bool = False,
    old_flag: bool = False,
    eccen_rotation: float | None = None,
    polar_rotation: float | None = None,
    eccen_output: float | None = None,
    polar_output: float | None = None,
    eccen_sfa_file: InputPathType | None = None,
    polar_sfa_file: InputPathType | None = None,
    sfa_dir: str | None = None,
    sfa_true_flag: bool = False,
    debug_flag: bool = False,
    checkopts_flag: bool = False,
    help_flag: bool = False,
    version_flag: bool = False,
    runner: Runner | None = None,
) -> MriFieldsignOutputs:
    """
    Field Sign Mapping Tool from FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        fieldsign_file: Output field sign file.
        eccen_values: Eccentricity values (real and imaginary).
        polar_values: Polar values (real and imaginary).
        subject: Subject identifier.
        hemisphere: Hemisphere to process.
        patch_file: Patch file, without hemi.
        occip_flag: Use occipital patch (patchfile = occip.patch.flat).
        sphere_flag: Use spherical surface instead of patch.
        fwhm: Full-width at half-maximum (mm).
        nsmooth: Number of smoothing steps.
        reverse_flag: Reverse sign.
        old_flag: Use old FS estimation code.
        eccen_rotation: Rotate eccentricity by rotangle degrees.
        polar_rotation: Rotate polar by rotangle degrees.
        eccen_output: Output eccentricity angle.
        polar_output: Output polar angle.
        eccen_sfa_file: Eccentricity self-frequency average file.
        polar_sfa_file: Polar self-frequency average file.
        sfa_dir: SFA directory.
        sfa_true_flag: Use true real and imaginary (affects small smoothing).
        debug_flag: Turn on debugging.
        checkopts_flag: Check options and exit.
        help_flag: Display help information.
        version_flag: Print version and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriFieldsignOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_FIELDSIGN_METADATA)
    cargs = []
    cargs.append("mri_fieldsign")
    cargs.extend([
        "--fs",
        fieldsign_file
    ])
    cargs.extend([
        "--eccen",
        *map(str, eccen_values)
    ])
    cargs.extend([
        "--polar",
        *map(str, polar_values)
    ])
    cargs.extend([
        "--s",
        subject
    ])
    cargs.extend([
        "--hemi",
        hemisphere
    ])
    if patch_file is not None:
        cargs.extend([
            "--patch",
            patch_file
        ])
    if occip_flag:
        cargs.append("--occip")
    if sphere_flag:
        cargs.append("--sphere")
    if fwhm is not None:
        cargs.extend([
            "--fwhm",
            str(fwhm)
        ])
    if nsmooth is not None:
        cargs.extend([
            "--nsmooth",
            str(nsmooth)
        ])
    if reverse_flag:
        cargs.append("--rev")
    if old_flag:
        cargs.append("--old")
    if eccen_rotation is not None:
        cargs.extend([
            "--eccen-rot",
            str(eccen_rotation)
        ])
    if polar_rotation is not None:
        cargs.extend([
            "--polar-rot",
            str(polar_rotation)
        ])
    if eccen_output is not None:
        cargs.extend([
            "--eccen-out",
            str(eccen_output)
        ])
    if polar_output is not None:
        cargs.extend([
            "--polar-out",
            str(polar_output)
        ])
    if eccen_sfa_file is not None:
        cargs.extend([
            "--eccen-sfa",
            execution.input_file(eccen_sfa_file)
        ])
    if polar_sfa_file is not None:
        cargs.extend([
            "--polar-sfa",
            execution.input_file(polar_sfa_file)
        ])
    if sfa_dir is not None:
        cargs.extend([
            "--sfa",
            sfa_dir
        ])
    if sfa_true_flag:
        cargs.append("--sfa-true")
    if debug_flag:
        cargs.append("--debug")
    if checkopts_flag:
        cargs.append("--checkopts")
    if help_flag:
        cargs.append("--help")
    if version_flag:
        cargs.append("--version")
    ret = MriFieldsignOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_FIELDSIGN_METADATA",
    "MriFieldsignOutputs",
    "mri_fieldsign",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_HEAD_METADATA = Metadata(
    id="fb167e02a7257ba8b9a2343709e24ec6a1664305.boutiques",
    name="mri_head",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriHeadOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_head(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mri_head(
    identify: bool = False,
    read: bool = False,
    filename: str | None = None,
    question_mark_help: bool = False,
    runner: Runner | None = None,
) -> MriHeadOutputs:
    """
    No description.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        identify: Identify the MRI file.
        read: Read the MRI file.
        filename: Filename for identification or reading.
        question_mark_help: Display help or usage information.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriHeadOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_HEAD_METADATA)
    cargs = []
    cargs.append("mri_head")
    if identify:
        cargs.append("-identify")
    if read:
        cargs.append("-read")
    if filename is not None:
        cargs.append(filename)
    if question_mark_help:
        cargs.append("-?")
    ret = MriHeadOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_HEAD_METADATA",
    "MriHeadOutputs",
    "mri_head",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

METRIC_ROIS_TO_BORDER_METADATA = Metadata(
    id="7055195b90d96406ade3173df1aa38a66c4c45c1.boutiques",
    name="metric-rois-to-border",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class MetricRoisToBorderOutputs(typing.NamedTuple):
    """
    Output object returned when calling `metric_rois_to_border(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    border_out: OutputPathType
    """the output border file"""


def metric_rois_to_border(
    surface: InputPathType,
    metric: InputPathType,
    class_name: str,
    border_out: str,
    opt_placement_fraction: float | None = None,
    opt_column_column: str | None = None,
    runner: Runner | None = None,
) -> MetricRoisToBorderOutputs:
    """
    Draw borders around metric rois.
    
    For each ROI column, finds all edges on the mesh that cross the boundary of
    the ROI, and draws borders through them. By default, this is done on all
    columns in the input file, using the map name as the name for the border.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        surface: the surface to use for neighbor information.
        metric: the input metric containing ROIs.
        class_name: the name to use for the class of the output borders.
        border_out: the output border file.
        opt_placement_fraction: set how far along the edge border points are\
            drawn: fraction along edge from inside vertex (default 0.33).
        opt_column_column: select a single column: the column number or name.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MetricRoisToBorderOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(METRIC_ROIS_TO_BORDER_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-metric-rois-to-border")
    cargs.append(execution.input_file(surface))
    cargs.append(execution.input_file(metric))
    cargs.append(class_name)
    cargs.append(border_out)
    if opt_placement_fraction is not None:
        cargs.extend([
            "-placement",
            str(opt_placement_fraction)
        ])
    if opt_column_column is not None:
        cargs.extend([
            "-column",
            opt_column_column
        ])
    ret = MetricRoisToBorderOutputs(
        root=execution.output_file("."),
        border_out=execution.output_file(border_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "METRIC_ROIS_TO_BORDER_METADATA",
    "MetricRoisToBorderOutputs",
    "metric_rois_to_border",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MEANVAL_METADATA = Metadata(
    id="abff5f1715da97f4e48f1b5b12b06bbfdebcd6e0.boutiques",
    name="meanval",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MeanvalOutputs(typing.NamedTuple):
    """
    Output object returned when calling `meanval(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    mean_output_file: OutputPathType
    """File containing the mean value calculated"""


def meanval(
    input_file: InputPathType,
    mask_file: InputPathType,
    output_file: str,
    avgwf_flag: bool = False,
    runner: Runner | None = None,
) -> MeanvalOutputs:
    """
    Tool to calculate the mean value of an image within a mask.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_file: Input volume file.
        mask_file: Mask file.
        output_file: Output file where mean value will be stored.
        avgwf_flag: Flag to calculate the average waveform.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MeanvalOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MEANVAL_METADATA)
    cargs = []
    cargs.append("meanval")
    cargs.extend([
        "--i",
        execution.input_file(input_file)
    ])
    cargs.extend([
        "--m",
        execution.input_file(mask_file)
    ])
    cargs.extend([
        "--o",
        output_file
    ])
    if avgwf_flag:
        cargs.append("--avgwf")
    ret = MeanvalOutputs(
        root=execution.output_file("."),
        mean_output_file=execution.output_file(output_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MEANVAL_METADATA",
    "MeanvalOutputs",
    "meanval",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SPHERE_SUBJECT_LH_METADATA = Metadata(
    id="6cb29acf4c0a72caae7b4c3b000c37495ed423e6.boutiques",
    name="sphere_subject-lh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class SphereSubjectLhOutputs(typing.NamedTuple):
    """
    Output object returned when calling `sphere_subject_lh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def sphere_subject_lh(
    license_file: InputPathType,
    runner: Runner | None = None,
) -> SphereSubjectLhOutputs:
    """
    Tool for processing spherical representations in FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        license_file: Path to the FreeSurfer license file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SphereSubjectLhOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SPHERE_SUBJECT_LH_METADATA)
    cargs = []
    cargs.extend([
        "-lh",
        "sphere_subject" + execution.input_file(license_file)
    ])
    ret = SphereSubjectLhOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SPHERE_SUBJECT_LH_METADATA",
    "SphereSubjectLhOutputs",
    "sphere_subject_lh",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FAT_MVM_SCRIPTER_PY_METADATA = Metadata(
    id="2b93a491c79b77f3d34fa9c5577a2b3807db847a.boutiques",
    name="fat_mvm_scripter.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class FatMvmScripterPyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fat_mvm_scripter_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    generated_script: OutputPathType
    """Script for running 3dMVM, using the prescribed variables along with each
    individual parameter."""
    results_file: OutputPathType
    """Text file of the test results."""


def fat_mvm_scripter_py(
    prefix: str,
    table: InputPathType,
    log: InputPathType,
    vars_: str | None = None,
    file_vars: InputPathType | None = None,
    pars: str | None = None,
    file_pars: InputPathType | None = None,
    rois: str | None = None,
    file_rois: InputPathType | None = None,
    no_posthoc: bool = False,
    na_warn_off: bool = False,
    subnet_pref: str | None = None,
    cat_pair_off: bool = False,
    runner: Runner | None = None,
) -> FatMvmScripterPyOutputs:
    """
    Automated tool to create command scripts for 3dMVM statistical modeling.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        prefix: Output prefix for the script file, which will ultimately create\
            a PREFIX_MVM.txt file of statistical results from 3dMVM.
        table: Text file containing columns of subject data, one subject per\
            row, formatted as a *_MVMtbl.txt output by fat_mvm_prep.py.
        log: File formatted according to fat_mvm_prep.py containing commented\
            headings and lists of cross-group ROIs and parameters.
        vars_: List of variables for the 3dMVM model. Names must be separated\
            with whitespace. Categorical variables will be detected automatically\
            by the presence of nonnumeric characters in their columns.
        file_vars: Second method for supplying a list of variables for 3dMVM.\
            VAR_FILE is a text file with a single column of variable names.
        pars: List of parameters (names of matrices) to run in distinct 3dMVM\
            models. Names must be separated with whitespace.
        file_pars: Second method for supplying a list of parameters for 3dMVM\
            runs. PAR_FILE is a text file with a single column of parameter names.
        rois: Optional command to select a subset of available network ROIs.\
            Names must be separated with whitespace.
        file_rois: Second method for supplying a subset of ROIs for 3dMVM runs.\
            ROI_FILE is a text file with a single column of variable names.
        no_posthoc: Switch to turn off the automatic generation of per-ROI post\
            hoc tests.
        na_warn_off: Switch to turn off the automatic warnings as the data\
            table is created. 3dMVM will excise subjects with NA values, so there\
            shouldn't be NA values in columns you want to model.
        subnet_pref: Name SUBPR for the new table file that is created when a\
            subnetwork list of ROIs is used.
        cat_pair_off: Switch to turn off the test for categorical variables\
            undergoing posthoc testing.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FatMvmScripterPyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FAT_MVM_SCRIPTER_PY_METADATA)
    cargs = []
    cargs.append("fat_mvm_scripter.py")
    cargs.extend([
        "--prefix",
        prefix
    ])
    cargs.extend([
        "--table",
        execution.input_file(table)
    ])
    cargs.extend([
        "--log",
        execution.input_file(log)
    ])
    if vars_ is not None:
        cargs.extend([
            "--vars",
            vars_
        ])
    if file_vars is not None:
        cargs.extend([
            "--file_vars",
            execution.input_file(file_vars)
        ])
    if pars is not None:
        cargs.extend([
            "--Pars",
            pars
        ])
    if file_pars is not None:
        cargs.extend([
            "--File_Pars",
            execution.input_file(file_pars)
        ])
    if rois is not None:
        cargs.extend([
            "--rois",
            rois
        ])
    if file_rois is not None:
        cargs.extend([
            "--file_rois",
            execution.input_file(file_rois)
        ])
    if no_posthoc:
        cargs.append("--no_posthoc")
    if na_warn_off:
        cargs.append("--NA_warn_off")
    if subnet_pref is not None:
        cargs.extend([
            "--subnet_pref",
            subnet_pref
        ])
    if cat_pair_off:
        cargs.append("--cat_pair_off")
    ret = FatMvmScripterPyOutputs(
        root=execution.output_file("."),
        generated_script=execution.output_file(prefix + "_scri.tcsh"),
        results_file=execution.output_file(prefix + "_MVM.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FAT_MVM_SCRIPTER_PY_METADATA",
    "FatMvmScripterPyOutputs",
    "fat_mvm_scripter_py",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SET_SPACING_METADATA = Metadata(
    id="b77674b8a0a6a1121f61d0814da8fcf1ba54b3f8.boutiques",
    name="SetSpacing",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


class SetSpacingOutputs(typing.NamedTuple):
    """
    Output object returned when calling `set_spacing(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_image: OutputPathType
    """The output image with the specified spacing."""


def set_spacing(
    dimension: int,
    input_file: InputPathType,
    output_file: InputPathType,
    spacing: list[float],
    runner: Runner | None = None,
) -> SetSpacingOutputs:
    """
    A tool to set the spacing of an image in each dimension.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        dimension: The dimensionality of the image (e.g., 2 or 3).
        input_file: The input image file in HDR format.
        output_file: The output image file in NII format.
        spacing: Spacing values for each dimension. Requires SpacingX,\
            SpacingY, and optionally SpacingZ.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SetSpacingOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SET_SPACING_METADATA)
    cargs = []
    cargs.append("SetSpacing")
    cargs.append(str(dimension))
    cargs.append(execution.input_file(input_file))
    cargs.append(execution.input_file(output_file))
    cargs.extend(map(str, spacing))
    ret = SetSpacingOutputs(
        root=execution.output_file("."),
        output_image=execution.output_file(pathlib.Path(output_file).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SET_SPACING_METADATA",
    "SetSpacingOutputs",
    "set_spacing",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

DMRI_FORREST_METADATA = Metadata(
    id="dd4542253804128ad899a822733de446938568c4.boutiques",
    name="dmri_forrest",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class DmriForrestOutputs(typing.NamedTuple):
    """
    Output object returned when calling `dmri_forrest(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def dmri_forrest(
    test_dir: str,
    train_file: InputPathType,
    mask_file: InputPathType,
    tract_files: list[InputPathType],
    seg_file: InputPathType | None = None,
    diff_file: InputPathType | None = None,
    debug: bool = False,
    checkopts: bool = False,
    runner: Runner | None = None,
) -> DmriForrestOutputs:
    """
    dmri_forrest is a tool for processing diffusion MRI data using a random
    forest-based method.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        test_dir: Directory containing the test subject data.
        train_file: File listing training subject directories, one per line.
        mask_file: Input brain mask volume name, relative to subject directory.
        tract_files: Input tract label volume(s), relative to subject directory.
        seg_file: Input aparc+aseg volume name, relative to subject directory.
        diff_file: Input diffusion orientation volume name, relative to subject\
            directory.
        debug: Turn on debugging mode.
        checkopts: Only check options and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `DmriForrestOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(DMRI_FORREST_METADATA)
    cargs = []
    cargs.append("dmri_forrest")
    cargs.extend([
        "--test",
        test_dir
    ])
    cargs.extend([
        "--train",
        execution.input_file(train_file)
    ])
    cargs.extend([
        "--mask",
        execution.input_file(mask_file)
    ])
    cargs.extend([
        "--tract",
        *[execution.input_file(f) for f in tract_files]
    ])
    if seg_file is not None:
        cargs.extend([
            "--seg",
            execution.input_file(seg_file)
        ])
    if diff_file is not None:
        cargs.extend([
            "--diff",
            execution.input_file(diff_file)
        ])
    if debug:
        cargs.append("--debug")
    if checkopts:
        cargs.append("--checkopts")
    ret = DmriForrestOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "DMRI_FORREST_METADATA",
    "DmriForrestOutputs",
    "dmri_forrest",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_REMESH_METADATA = Metadata(
    id="2952fb621021ef623340899d397234ce68e0a747.boutiques",
    name="mris_remesh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisRemeshOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_remesh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    remeshed_output: OutputPathType
    """Remeshed output surface file"""


def mris_remesh(
    input_: InputPathType,
    output: InputPathType,
    edge_length: float | None = None,
    num_vertices: float | None = None,
    face_area: float | None = None,
    remesh: bool = False,
    iterations: float | None = None,
    runner: Runner | None = None,
) -> MrisRemeshOutputs:
    """
    Remeshes a surface to a desired edge length, number of vertices, or average face
    area.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_: Input surface file.
        output: Output surface file.
        edge_length: Target average edge length in mm for remeshed surface.
        num_vertices: Target number of vertices for remeshed surface.
        face_area: Desired average face area in mm².
        remesh: Improve the quality while only reducing vertices by a small\
            amount.
        iterations: Number of remeshing iterations (default is 5).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisRemeshOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_REMESH_METADATA)
    cargs = []
    cargs.append("mris_remesh")
    cargs.extend([
        "-i",
        execution.input_file(input_)
    ])
    cargs.extend([
        "-o",
        execution.input_file(output)
    ])
    if edge_length is not None:
        cargs.extend([
            "--edge-len",
            str(edge_length)
        ])
    if num_vertices is not None:
        cargs.extend([
            "--nvert",
            str(num_vertices)
        ])
    if face_area is not None:
        cargs.extend([
            "--desired-face-area",
            str(face_area)
        ])
    if remesh:
        cargs.append("--remesh")
    if iterations is not None:
        cargs.extend([
            "--iters",
            str(iterations)
        ])
    ret = MrisRemeshOutputs(
        root=execution.output_file("."),
        remeshed_output=execution.output_file(pathlib.Path(output).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_REMESH_METADATA",
    "MrisRemeshOutputs",
    "mris_remesh",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ADD_NOISE_TO_IMAGE_METADATA = Metadata(
    id="e8efbf11871081a5ad3301baf672f8de93471bd0.boutiques",
    name="AddNoiseToImage",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


class AddNoiseToImageOutputs(typing.NamedTuple):
    """
    Output object returned when calling `add_noise_to_image(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    noise_corrupted_image: OutputPathType
    """The output is the noise corrupted version of the input image."""


def add_noise_to_image(
    input_image: InputPathType,
    noise_model: typing.Literal["AdditiveGaussian", "SaltAndPepper", "Shot", "Speckle"],
    output: InputPathType,
    image_dimensionality: typing.Literal[2, 3, 4] | None = None,
    verbose: typing.Literal[0, 1] | None = None,
    runner: Runner | None = None,
) -> AddNoiseToImageOutputs:
    """
    Add various types of noise to an image.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        input_image: A scalar image is expected as input for noise correction.
        noise_model: Use different noise models each with its own (default)\
            parameters.
        output: The output consists of the noise corrupted version of the input\
            image.
        image_dimensionality: This option forces the image to be treated as a\
            specified-dimensional image. If not specified, the program tries to\
            infer the dimensionality from the input image.
        verbose: Verbose output.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AddNoiseToImageOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ADD_NOISE_TO_IMAGE_METADATA)
    cargs = []
    cargs.append("AddNoiseToImage")
    if image_dimensionality is not None:
        cargs.extend([
            "--image-dimensionality",
            str(image_dimensionality)
        ])
    cargs.extend([
        "--input-image",
        execution.input_file(input_image)
    ])
    cargs.extend([
        "--noise-model",
        noise_model
    ])
    cargs.extend([
        "--output",
        execution.input_file(output)
    ])
    if verbose is not None:
        cargs.extend([
            "--verbose",
            str(verbose)
        ])
    ret = AddNoiseToImageOutputs(
        root=execution.output_file("."),
        noise_corrupted_image=execution.output_file(pathlib.Path(output).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ADD_NOISE_TO_IMAGE_METADATA",
    "AddNoiseToImageOutputs",
    "add_noise_to_image",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_SKELETONIZE_METADATA = Metadata(
    id="0b067079e3dfa4d5ff1e1cf5bf10adf3ec69d818.boutiques",
    name="mris_skeletonize",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisSkeletonizeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_skeletonize(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    skeleton_output: OutputPathType | None
    """Output skeletonized mask."""
    pointset_output: OutputPathType | None
    """Output point set of the skeleton."""
    skeleton_label: OutputPathType | None
    """Label file for the skeletonized output."""


def mris_skeletonize(
    surface: str,
    surfvals: str,
    mask: str,
    k1: bool = False,
    curv_nonmaxsup: bool = False,
    gyrus: bool = False,
    sulcus: bool = False,
    outdir: str | None = None,
    sphere: str | None = None,
    pointset: str | None = None,
    label: str | None = None,
    nbrsize: float | None = 2,
    threshold: float | None = None,
    cluster: float | None = None,
    fwhm: float | None = None,
    runner: Runner | None = None,
) -> MrisSkeletonizeOutputs:
    """
    Computes the skeleton of gyri (ie, the crowns) or sulci (ie, the fundi).
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        surface: Path to the surface file.
        surfvals: Pass input explicitly rather than computing it.
        mask: Final skeletonized mask file.
        k1: Use k1 from surface (not with --curv-nonmaxsup).
        curv_nonmaxsup: Use curvature H computed from surface with non-max\
            suppression (not with --k1).
        gyrus: Skeletonize the crowns of the gyri.
        sulcus: Skeletonize the fundi of the sulci.
        outdir: Directory where all outputs will be saved.
        sphere: Sphere path, only needed for nonmax suppression.
        pointset: Point set of the skeleton (PointSet.json).
        label: Surface label of the skeleton (label file path).
        nbrsize: Neighborhood size for 2nd FF (default is 2).
        threshold: Used to create initial mask that will be skeletonized\
            (typically about 0.3).
        cluster: Cluster the thresholded input and keep the largest nkeep\
            clusters.
        fwhm: Smooth surface values by this FWHM.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisSkeletonizeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_SKELETONIZE_METADATA)
    cargs = []
    cargs.append("mris_skeletonize")
    cargs.extend([
        "--surf",
        surface
    ])
    cargs.extend([
        "--surfvals",
        surfvals
    ])
    cargs.extend([
        "--mask",
        mask
    ])
    if k1:
        cargs.append("--k1")
    if curv_nonmaxsup:
        cargs.append("--curv-nonmaxsup")
    if gyrus:
        cargs.append("--gyrus")
    if sulcus:
        cargs.append("--sulcus")
    if outdir is not None:
        cargs.extend([
            "--outdir",
            outdir
        ])
    if sphere is not None:
        cargs.extend([
            "--sphere",
            sphere
        ])
    if pointset is not None:
        cargs.extend([
            "--ps",
            pointset
        ])
    if label is not None:
        cargs.extend([
            "--label",
            label
        ])
    if nbrsize is not None:
        cargs.extend([
            "--nbrsize",
            str(nbrsize)
        ])
    if threshold is not None:
        cargs.extend([
            "--threshold",
            str(threshold)
        ])
    if cluster is not None:
        cargs.extend([
            "--cluster",
            str(cluster)
        ])
    if fwhm is not None:
        cargs.extend([
            "--fwhm",
            str(fwhm)
        ])
    ret = MrisSkeletonizeOutputs(
        root=execution.output_file("."),
        skeleton_output=execution.output_file(outdir + "/skeleton.mgz") if (outdir is not None) else None,
        pointset_output=execution.output_file(outdir + "/PointSet.json") if (outdir is not None) else None,
        skeleton_label=execution.output_file(outdir + "/skeleton_label.mgz") if (outdir is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_SKELETONIZE_METADATA",
    "MrisSkeletonizeOutputs",
    "mris_skeletonize",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_SAMPLE_PARC_METADATA = Metadata(
    id="63fdac72bbfef323f1126c39c936ff5c938f8b5d.boutiques",
    name="mris_sample_parc",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisSampleParcOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_sample_parc(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outfile: OutputPathType
    """Output annotation file."""


def mris_sample_parc(
    subject_name: str,
    hemisphere: str,
    parc_name: str,
    output_annot: str,
    sdir: str | None = None,
    surf: str | None = None,
    fix: float | None = None,
    replace: float | None = None,
    trans: list[float] | None = None,
    cortex: str | None = None,
    projmm: float | None = None,
    proj: float | None = None,
    projfrac: float | None = None,
    file: str | None = None,
    ct: str | None = None,
    v_level: float | None = None,
    filter_: float | None = None,
    smooth: float | None = None,
    w_size: float | None = None,
    thickness: str | None = None,
    change_unknown: float | None = None,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> MrisSampleParcOutputs:
    """
    This program samples a volumetric parcellation onto a surface.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject_name: The subject ID.
        hemisphere: Hemisphere: rh or lh.
        parc_name: Parcellation filename.
        output_annot: Output annotation filename.
        sdir: Use as subjects directory (default: $SUBJECTS_DIR).
        surf: Use as surface (default: 'white').
        fix: Fix topology of all labels smaller than the specified number of\
            vertices (default=-1, do all).
        replace: Replace label with deeper ones.
        trans: Translate one label number to another.
        cortex: Mask regions outside of the specified cortex label.
        projmm: Project the specified number of millimeters along surface\
            normal (default=0.0).
        proj: Same as -projmm.
        projfrac: Project the specified percent along surface normal\
            (default=0.5).
        file: Use as translation file (default: 'cma_parcellation_colors.txt').
        ct: Embed color table into output annotation file.
        v_level: Diagnostic level (default=0).
        filter_: Apply mode filter a specified number of times to parcellation\
            (default=0).
        smooth: Smooth surface a specified number of times (default=0).
        w_size: Use window size for sampling (default=7).
        thickness: Use thickness file (default: 'thickness').
        change_unknown: Change largest connected unknown region to specified\
            label (default: don't change).
        help_: Print help info.
        version: Print version info.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisSampleParcOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_SAMPLE_PARC_METADATA)
    cargs = []
    cargs.append("mris_sample_parc")
    cargs.append(subject_name)
    cargs.append(hemisphere)
    cargs.append(parc_name)
    cargs.append(output_annot)
    if sdir is not None:
        cargs.extend([
            "-sdir",
            sdir
        ])
    if surf is not None:
        cargs.extend([
            "-surf",
            surf
        ])
    if fix is not None:
        cargs.extend([
            "-fix",
            str(fix)
        ])
    if replace is not None:
        cargs.extend([
            "-replace",
            str(replace)
        ])
    if trans is not None:
        cargs.extend([
            "-trans",
            *map(str, trans)
        ])
    if cortex is not None:
        cargs.extend([
            "-cortex",
            cortex
        ])
    if projmm is not None:
        cargs.extend([
            "-projmm",
            str(projmm)
        ])
    if proj is not None:
        cargs.extend([
            "-proj",
            str(proj)
        ])
    if projfrac is not None:
        cargs.extend([
            "-projfrac",
            str(projfrac)
        ])
    if file is not None:
        cargs.extend([
            "-file",
            file
        ])
    if ct is not None:
        cargs.extend([
            "-ct",
            ct
        ])
    if v_level is not None:
        cargs.extend([
            "-v",
            str(v_level)
        ])
    if filter_ is not None:
        cargs.extend([
            "-f",
            str(filter_)
        ])
    if smooth is not None:
        cargs.extend([
            "-a",
            str(smooth)
        ])
    if w_size is not None:
        cargs.extend([
            "-w",
            str(w_size)
        ])
    if thickness is not None:
        cargs.extend([
            "-t",
            thickness
        ])
    if change_unknown is not None:
        cargs.extend([
            "-u",
            str(change_unknown)
        ])
    if help_:
        cargs.append("--help")
    if version:
        cargs.append("--version")
    ret = MrisSampleParcOutputs(
        root=execution.output_file("."),
        outfile=execution.output_file(output_annot),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_SAMPLE_PARC_METADATA",
    "MrisSampleParcOutputs",
    "mris_sample_parc",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

WAVER_METADATA = Metadata(
    id="853f5c7b1276e654db54518623370e48705e17ef.boutiques",
    name="waver",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class WaverOutputs(typing.NamedTuple):
    """
    Output object returned when calling `waver(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_filename: OutputPathType
    """The output filename for the result of the waveform."""


def waver(
    wav: bool = False,
    gam: bool = False,
    expr: str | None = None,
    file_opt: str | None = None,
    delay_time: float | None = None,
    rise_time: float | None = None,
    fall_time: float | None = None,
    undershoot: float | None = None,
    restore_time: float | None = None,
    gamb: float | None = None,
    gamc: float | None = None,
    gamd: float | None = None,
    peak: float | None = None,
    dt: float | None = None,
    tr: float | None = None,
    xyout: bool = False,
    input_file: InputPathType | None = None,
    inline_data: str | None = None,
    tstim_data: str | None = None,
    when_data: str | None = None,
    numout: int | None = None,
    ver_flag: bool = False,
    runner: Runner | None = None,
) -> WaverOutputs:
    """
    Creates an ideal waveform timeseries file.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        wav: Sets waveform to Cox special [default].
        gam: Sets waveform to form t^b * exp(-t/c) (cf. Mark Cohen).
        expr: Sets waveform to the expression given, which should depend on the\
            variable 't'.
        file_opt: Sets waveform to the values read from the file wname, which\
            should be a single column .1D file. The dt value is the time step (in\
            seconds) between lines in wname.
        delay_time: Sets delay time to # seconds [2].
        rise_time: Sets rise time to # seconds [4].
        fall_time: Sets fall time to # seconds [6].
        undershoot: Sets undershoot to # times the peak [0.2].
        restore_time: Sets time to restore from undershoot [2].
        gamb: Sets the parameter 'b' to # [8.6].
        gamc: Sets the parameter 'c' to # [0.547].
        gamd: Sets the delay time to # seconds [0.0].
        peak: Sets peak value to # [100].
        dt: Sets time step of output AND input [0.1].
        tr: '-TR' is equivalent to '-dt'.
        xyout: Output data in 2 columns: 1=time 2=waveform (useful for\
            graphing) [default is 1 column=waveform].
        input_file: Read timeseries from *.1D formatted 'infile'; convolve with\
            waveform to produce output.
        inline_data: Read timeseries from command line DATA; convolve with\
            waveform to produce output.
        tstim_data: Read discrete stimulation times from the command line and\
            convolve the waveform with delta-functions at those times.
        when_data: Read time blocks when stimulus is 'on' (=1) from the command\
            line and convolve the waveform with with a zero-one input.
        numout: Output a timeseries with NN points; if this option is not\
            given, then enough points are output to let the result tail back down\
            to zero.
        ver_flag: Output version information and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `WaverOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(WAVER_METADATA)
    cargs = []
    cargs.append("waver")
    if wav:
        cargs.append("-WAV")
    if gam:
        cargs.append("-GAM")
    if expr is not None:
        cargs.extend([
            "-EXPR",
            expr
        ])
    if file_opt is not None:
        cargs.extend([
            "-FILE",
            file_opt
        ])
    if delay_time is not None:
        cargs.extend([
            "-delaytime",
            str(delay_time)
        ])
    if rise_time is not None:
        cargs.extend([
            "-risetime",
            str(rise_time)
        ])
    if fall_time is not None:
        cargs.extend([
            "-falltime",
            str(fall_time)
        ])
    if undershoot is not None:
        cargs.extend([
            "-undershoot",
            str(undershoot)
        ])
    if restore_time is not None:
        cargs.extend([
            "-restoretime",
            str(restore_time)
        ])
    if gamb is not None:
        cargs.extend([
            "-gamb",
            str(gamb)
        ])
    if gamc is not None:
        cargs.extend([
            "-gamc",
            str(gamc)
        ])
    if gamd is not None:
        cargs.extend([
            "-gamd",
            str(gamd)
        ])
    if peak is not None:
        cargs.extend([
            "-peak",
            str(peak)
        ])
    if dt is not None:
        cargs.extend([
            "-dt",
            str(dt)
        ])
    if tr is not None:
        cargs.extend([
            "-TR",
            str(tr)
        ])
    if xyout:
        cargs.append("-xyout")
    if input_file is not None:
        cargs.extend([
            "-input",
            execution.input_file(input_file)
        ])
    if inline_data is not None:
        cargs.extend([
            "-inline",
            inline_data
        ])
    if tstim_data is not None:
        cargs.extend([
            "-tstim",
            tstim_data
        ])
    if when_data is not None:
        cargs.extend([
            "-when",
            when_data
        ])
    if numout is not None:
        cargs.extend([
            "-numout",
            str(numout)
        ])
    if ver_flag:
        cargs.append("-ver")
    ret = WaverOutputs(
        root=execution.output_file("."),
        output_filename=execution.output_file("output_filename"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "WAVER_METADATA",
    "WaverOutputs",
    "waver",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_PVMAP_METADATA = Metadata(
    id="55dba5084ade4c336efba69e81addccf3e2d93a3.boutiques",
    name="3dPVmap",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dPvmapOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_pvmap(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outbrik: OutputPathType | None
    """Output PVmap file"""
    outhead: OutputPathType | None
    """Output PVmap header file"""
    pc_vectors: OutputPathType | None
    """Principal component time series vectors"""


def v_3d_pvmap(
    inputdataset: InputPathType,
    prefix: str | None = None,
    mask: InputPathType | None = None,
    automask: bool = False,
    runner: Runner | None = None,
) -> V3dPvmapOutputs:
    """
    Computes the first two principal component vectors of a time series dataset,
    then outputs the R-squared coefficient of each voxel time series with these
    first two components.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        inputdataset: Input dataset (e.g., fred.nii).
        prefix: Output prefix for generated files.
        mask: Mask dataset (e.g., brainmask.nii).
        automask: Automatically generate a mask from the input dataset.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dPvmapOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_PVMAP_METADATA)
    cargs = []
    cargs.append("3dPVmap")
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    if automask:
        cargs.append("-automask")
    cargs.append(execution.input_file(inputdataset))
    ret = V3dPvmapOutputs(
        root=execution.output_file("."),
        outbrik=execution.output_file(prefix + "+orig.BRIK") if (prefix is not None) else None,
        outhead=execution.output_file(prefix + "+orig.HEAD") if (prefix is not None) else None,
        pc_vectors=execution.output_file(prefix + ".1D") if (prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dPvmapOutputs",
    "V_3D_PVMAP_METADATA",
    "v_3d_pvmap",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ANALYZETO4DFP_METADATA = Metadata(
    id="68ba555395398681b7b2f785a91ccbac22cbddc9.boutiques",
    name="analyzeto4dfp",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class Analyzeto4dfpOutputs(typing.NamedTuple):
    """
    Output object returned when calling `analyzeto4dfp(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def analyzeto4dfp(
    analyze_image: InputPathType,
    rois_scale: bool = False,
    flip_x: bool = False,
    flip_y: bool = False,
    flip_z: bool = False,
    endian: str | None = None,
    orientation: int | None = None,
    runner: Runner | None = None,
) -> Analyzeto4dfpOutputs:
    """
    Convert ANALYZE image format to 4dfp format with various options.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        analyze_image: Input ANALYZE image file.
        rois_scale: Apply ROIScaleFactor.
        flip_x: Flip first axis.
        flip_y: Flip second axis.
        flip_z: Flip third axis.
        endian: Output big or little endian (default CPU endian).
        orientation: Supply orientation code (in range [0-5]).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Analyzeto4dfpOutputs`).
    """
    if orientation is not None and not (0 <= orientation <= 5): 
        raise ValueError(f"'orientation' must be between 0 <= x <= 5 but was {orientation}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(ANALYZETO4DFP_METADATA)
    cargs = []
    cargs.append("analyzeto4dfp")
    cargs.append(execution.input_file(analyze_image))
    if rois_scale:
        cargs.append("-s")
    if flip_x:
        cargs.append("-x")
    if flip_y:
        cargs.append("-y")
    if flip_z:
        cargs.append("-z")
    if endian is not None:
        cargs.extend([
            "-@",
            endian
        ])
    if orientation is not None:
        cargs.extend([
            "-O",
            str(orientation)
        ])
    ret = Analyzeto4dfpOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ANALYZETO4DFP_METADATA",
    "Analyzeto4dfpOutputs",
    "analyzeto4dfp",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_TSHIFT_METADATA = Metadata(
    id="1e963c8aacff12ed5089324cd001cc9158093823.boutiques",
    name="3dTshift",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dTshiftOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_tshift(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_file: OutputPathType | None
    """Output image file name."""
    timing_file: OutputPathType
    """Afni formatted timing file, if ``slice_timing`` is a list."""


def v_3d_tshift(
    in_file: InputPathType,
    prefix: str | None = None,
    ignore: int | None = None,
    interp: typing.Literal["Fourier", "linear", "cubic", "quintic", "heptic"] | None = None,
    num_threads: int | None = None,
    outputtype: typing.Literal["NIFTI", "AFNI", "NIFTI_GZ"] | None = None,
    rlt: bool = False,
    rltplus: bool = False,
    slice_encoding_direction: typing.Literal["k", "k-"] | None = None,
    tpattern: typing.Literal["alt+z", "altplus", "alt+z2", "alt-z", "altminus", "alt-z2", "seq+z", "seqplus", "seq-z", "seqminus"] | None = None,
    tr: float | None = None,
    tslice: int | None = None,
    tzero: float | None = None,
    runner: Runner | None = None,
) -> V3dTshiftOutputs:
    """
    Shifts voxel time series from input so that separate slices are aligned to the
    same temporal origin.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        in_file: Input file to 3dtshift.
        prefix: Prefix for output image file name.
        ignore: Ignore the first set of points specified.
        interp: 'fourier' or 'linear' or 'cubic' or 'quintic' or 'heptic'.\
            Different interpolation methods (see 3dtshift for details) default =\
            fourier.
        num_threads: Set number of threads.
        outputtype: 'nifti' or 'afni' or 'nifti_gz'. Afni output filetype.
        rlt: Before shifting, remove the mean and linear trend.
        rltplus: Before shifting, remove the mean and linear trend and later\
            put back the mean.
        slice_encoding_direction: 'k' or 'k-'. Direction in which slice_timing\
            is specified (default: k). if negative,slice_timing is defined in\
            reverse order, that is, the first entry corresponds to the slice with\
            the largest index, and the final entry corresponds to slice index zero.\
            only in effect when slice_timing is passed as list, not when it is\
            passed as file.
        tpattern: 'alt+z' or 'altplus' or 'alt+z2' or 'alt-z' or 'altminus' or\
            'alt-z2' or 'seq+z' or 'seqplus' or 'seq-z' or 'seqminus' or a string.\
            Use specified slice time pattern rather than one in header.
        tr: Manually set the tr. you can attach suffix "s" for seconds or "ms"\
            for milliseconds.
        tslice: Align each slice to time offset of given slice.
        tzero: Align each slice to given time offset.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dTshiftOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_TSHIFT_METADATA)
    cargs = []
    cargs.append("3dTshift")
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if ignore is not None:
        cargs.extend([
            "-ignore",
            str(ignore)
        ])
    cargs.append(execution.input_file(in_file))
    if interp is not None:
        cargs.extend([
            "-",
            interp
        ])
    if num_threads is not None:
        cargs.append(str(num_threads))
    if outputtype is not None:
        cargs.append(outputtype)
    if rlt:
        cargs.append("-rlt")
    if rltplus:
        cargs.append("-rlt+")
    if slice_encoding_direction is not None:
        cargs.append(slice_encoding_direction)
    if tpattern is not None:
        cargs.extend([
            "-tpattern",
            tpattern
        ])
    if tr is not None:
        cargs.extend([
            "-TR",
            str(tr)
        ])
    if tslice is not None:
        cargs.extend([
            "-slice",
            str(tslice)
        ])
    if tzero is not None:
        cargs.extend([
            "-tzero",
            str(tzero)
        ])
    ret = V3dTshiftOutputs(
        root=execution.output_file("."),
        out_file=execution.output_file(prefix) if (prefix is not None) else None,
        timing_file=execution.output_file("timing_file"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dTshiftOutputs",
    "V_3D_TSHIFT_METADATA",
    "v_3d_tshift",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FEAT2SEGSTATS_METADATA = Metadata(
    id="8af7d53f19100c1eda8294eeb0e717ad52e76435.boutiques",
    name="feat2segstats",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class Feat2segstatsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `feat2segstats(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    segstats_output: OutputPathType | None
    """Output segmentation statistics file"""


def feat2segstats(
    feat_dir: str,
    stat_: str,
    featdirfile: InputPathType | None = None,
    seg_vol: str | None = None,
    aseg_flag: bool = False,
    aparc_aseg_flag: bool = False,
    ctab: InputPathType | None = None,
    all_segs_flag: bool = False,
    copes_flag: bool = False,
    varcopes_flag: bool = False,
    zstats_flag: bool = False,
    pes_flag: bool = False,
    rvar: str | None = None,
    example_func: str | None = None,
    mask: str | None = None,
    mean_func: str | None = None,
    version_flag: bool = False,
    help_flag: bool = False,
    debug_flag: bool = False,
    nolog_flag: bool = False,
    runner: Runner | None = None,
) -> Feat2segstatsOutputs:
    """
    Computes segmentation summaries and stores output in
    featdir/freesurfer/segstats/segvol/statname.dat.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        feat_dir: Feat output directory.
        stat_: Statistical output.
        featdirfile: File with a list of feat directories.
        seg_vol: Segmentation volume.
        aseg_flag: Use aseg segmentation.
        aparc_aseg_flag: Use aparc+aseg segmentation.
        ctab: Color lookup table, default is\
            FREESURFER_HOME/FreeSurferColorLUT.txt.
        all_segs_flag: Report on all segments, even empty ones.
        copes_flag: Do all copes.
        varcopes_flag: Do all varcopes.
        zstats_flag: Do all zstats.
        pes_flag: Do all pes.
        rvar: Sigma squared values.
        example_func: Example function.
        mask: Probably not too useful.
        mean_func: Mean function.
        version_flag: Print version and exit.
        help_flag: Print help and exit.
        debug_flag: Turn on debugging.
        nolog_flag: Do not create a log file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Feat2segstatsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FEAT2SEGSTATS_METADATA)
    cargs = []
    cargs.append("feat2segstats")
    cargs.extend([
        "--feat",
        feat_dir
    ])
    if featdirfile is not None:
        cargs.extend([
            "--featdirfile",
            execution.input_file(featdirfile)
        ])
    if seg_vol is not None:
        cargs.extend([
            "--seg",
            seg_vol
        ])
    if aseg_flag:
        cargs.append("--aseg")
    if aparc_aseg_flag:
        cargs.append("--aparc+aseg")
    if ctab is not None:
        cargs.extend([
            "--ctab",
            execution.input_file(ctab)
        ])
    if all_segs_flag:
        cargs.append("--all-segs")
    if copes_flag:
        cargs.append("--copes")
    if varcopes_flag:
        cargs.append("--varcopes")
    if zstats_flag:
        cargs.append("--zstats")
    if pes_flag:
        cargs.append("--pes")
    if rvar is not None:
        cargs.extend([
            "--rvar",
            rvar
        ])
    if example_func is not None:
        cargs.extend([
            "--exf",
            example_func
        ])
    if mask is not None:
        cargs.extend([
            "--mask",
            mask
        ])
    if mean_func is not None:
        cargs.extend([
            "--mean_func",
            mean_func
        ])
    cargs.extend([
        "--stat",
        stat_
    ])
    if version_flag:
        cargs.append("--version")
    if help_flag:
        cargs.append("--help")
    if debug_flag:
        cargs.append("--debug")
    if nolog_flag:
        cargs.append("--nolog")
    ret = Feat2segstatsOutputs(
        root=execution.output_file("."),
        segstats_output=execution.output_file(feat_dir + "/freesurfer/segstats/" + seg_vol + "/" + stat_ + ".dat") if (seg_vol is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FEAT2SEGSTATS_METADATA",
    "Feat2segstatsOutputs",
    "feat2segstats",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

WARPINVERT_METADATA = Metadata(
    id="34bd9d16c822603308c19a28bf1253af52fb2b1c.boutiques",
    name="warpinvert",
    package="mrtrix",
    container_image_tag="mrtrix3/mrtrix3:3.0.4",
)


@dataclasses.dataclass
class WarpinvertConfig:
    """
    temporarily set the value of an MRtrix config file entry.
    """
    key: str
    """temporarily set the value of an MRtrix config file entry."""
    value: str
    """temporarily set the value of an MRtrix config file entry."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-config")
        cargs.append(self.key)
        cargs.append(self.value)
        return cargs


class WarpinvertOutputs(typing.NamedTuple):
    """
    Output object returned when calling `warpinvert(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out: OutputPathType
    """the output warp image."""


def warpinvert(
    in_: InputPathType,
    out: str,
    template: InputPathType | None = None,
    displacement: bool = False,
    info: bool = False,
    quiet: bool = False,
    debug: bool = False,
    force: bool = False,
    nthreads: int | None = None,
    config: list[WarpinvertConfig] | None = None,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> WarpinvertOutputs:
    """
    Invert a non-linear warp field.
    
    By default, this command assumes that the input warp field is a deformation
    field, i.e. each voxel stores the corresponding position in the other image
    (in scanner space), and the calculated output warp image will also be a
    deformation field. If the input warp field is instead a displacment field,
    i.e. where each voxel stores an offset from which to sample the other image
    (but still in scanner space), then the -displacement option should be used;
    the output warp field will additionally be calculated as a displacement
    field in this case.
    
    References:
    
    .
    
    Author: MRTrix3 Developers
    
    URL: https://www.mrtrix.org/
    
    Args:
        in_: the input warp image.
        out: the output warp image.
        template: define a template image grid for the output warp.
        displacement: indicates that the input warp field is a displacement\
            field; the output will also be a displacement field.
        info: display information messages.
        quiet: do not display information messages or progress status;\
            alternatively, this can be achieved by setting the MRTRIX_QUIET\
            environment variable to a non-empty string.
        debug: display debugging messages.
        force: force overwrite of output files (caution: using the same file as\
            input and output might cause unexpected behaviour).
        nthreads: use this number of threads in multi-threaded applications\
            (set to 0 to disable multi-threading).
        config: temporarily set the value of an MRtrix config file entry.
        help_: display this information page and exit.
        version: display version information and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `WarpinvertOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(WARPINVERT_METADATA)
    cargs = []
    cargs.append("warpinvert")
    if template is not None:
        cargs.extend([
            "-template",
            execution.input_file(template)
        ])
    if displacement:
        cargs.append("-displacement")
    if info:
        cargs.append("-info")
    if quiet:
        cargs.append("-quiet")
    if debug:
        cargs.append("-debug")
    if force:
        cargs.append("-force")
    if nthreads is not None:
        cargs.extend([
            "-nthreads",
            str(nthreads)
        ])
    if config is not None:
        cargs.extend([a for c in [s.run(execution) for s in config] for a in c])
    if help_:
        cargs.append("-help")
    if version:
        cargs.append("-version")
    cargs.append(execution.input_file(in_))
    cargs.append(out)
    ret = WarpinvertOutputs(
        root=execution.output_file("."),
        out=execution.output_file(out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "WARPINVERT_METADATA",
    "WarpinvertConfig",
    "WarpinvertOutputs",
    "warpinvert",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSL_TSPLOT_METADATA = Metadata(
    id="513d97a89b2d7d7fbbdf4805c10d76f49cbd30af.boutiques",
    name="fsl_tsplot",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class FslTsplotOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fsl_tsplot(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_png: OutputPathType
    """Output PNG file"""


def fsl_tsplot(
    input_files: str,
    output_file: str,
    title: str | None = None,
    legend_file: str | None = None,
    labels: str | None = None,
    ymin: float | None = None,
    ymax: float | None = None,
    xlabel: str | None = None,
    ylabel: str | None = None,
    height: float | None = None,
    width: float | None = None,
    unit: float | None = None,
    precision: float | None = None,
    sci_flag: bool = False,
    start_col: float | None = None,
    end_col: float | None = None,
    runner: Runner | None = None,
) -> FslTsplotOutputs:
    """
    Timeseries plotting tool from FSL.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        input_files: Comma-separated list of input file names (ASCII text\
            matrix, one column per timecourse).
        output_file: Output filename for the PNG file.
        title: Plot title.
        legend_file: File name of ASCII text file, one row per legend entry.
        labels: Comma-separated list of labels.
        ymin: Minimum y-value.
        ymax: Maximum y-value.
        xlabel: X-axis label.
        ylabel: Y-axis label.
        height: Plot height in pixels (default 150).
        width: Plot width in pixels (default 600).
        unit: Scaling units for x-axis (default 1...length of infile).
        precision: Precision of x-axis labels.
        sci_flag: Switch on scientific notation.
        start_col: Position of first column to plot.
        end_col: Position of final column to plot.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslTsplotOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSL_TSPLOT_METADATA)
    cargs = []
    cargs.append("fsl_tsplot")
    cargs.extend([
        "-i",
        input_files
    ])
    cargs.extend([
        "-o",
        output_file
    ])
    if title is not None:
        cargs.extend([
            "-t",
            title
        ])
    if legend_file is not None:
        cargs.extend([
            "-l",
            legend_file
        ])
    if labels is not None:
        cargs.extend([
            "-a",
            labels
        ])
    if ymin is not None:
        cargs.extend([
            "--ymin",
            str(ymin)
        ])
    if ymax is not None:
        cargs.extend([
            "--ymax",
            str(ymax)
        ])
    if xlabel is not None:
        cargs.extend([
            "-x",
            xlabel
        ])
    if ylabel is not None:
        cargs.extend([
            "-y",
            ylabel
        ])
    if height is not None:
        cargs.extend([
            "-h",
            str(height)
        ])
    if width is not None:
        cargs.extend([
            "-w",
            str(width)
        ])
    if unit is not None:
        cargs.extend([
            "-u",
            str(unit)
        ])
    if precision is not None:
        cargs.extend([
            "--precision",
            str(precision)
        ])
    if sci_flag:
        cargs.append("--sci")
    if start_col is not None:
        cargs.extend([
            "--start",
            str(start_col)
        ])
    if end_col is not None:
        cargs.extend([
            "--finish",
            str(end_col)
        ])
    ret = FslTsplotOutputs(
        root=execution.output_file("."),
        output_png=execution.output_file(output_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSL_TSPLOT_METADATA",
    "FslTsplotOutputs",
    "fsl_tsplot",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

DCMEDIT_METADATA = Metadata(
    id="01158fce9a81a53a1cc2f81c6577cb2f6210d5a8.boutiques",
    name="dcmedit",
    package="mrtrix",
    container_image_tag="mrtrix3/mrtrix3:3.0.4",
)


@dataclasses.dataclass
class DcmeditTag:
    """
    replace specific tag.
    """
    group: str
    """replace specific tag."""
    element: str
    """replace specific tag."""
    newvalue: str
    """replace specific tag."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-tag")
        cargs.append(self.group)
        cargs.append(self.element)
        cargs.append(self.newvalue)
        return cargs


@dataclasses.dataclass
class DcmeditConfig:
    """
    temporarily set the value of an MRtrix config file entry.
    """
    key: str
    """temporarily set the value of an MRtrix config file entry."""
    value: str
    """temporarily set the value of an MRtrix config file entry."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-config")
        cargs.append(self.key)
        cargs.append(self.value)
        return cargs


class DcmeditOutputs(typing.NamedTuple):
    """
    Output object returned when calling `dcmedit(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def dcmedit(
    file: InputPathType,
    anonymise: bool = False,
    id_: str | None = None,
    tag: list[DcmeditTag] | None = None,
    info: bool = False,
    quiet: bool = False,
    debug: bool = False,
    force: bool = False,
    nthreads: int | None = None,
    config: list[DcmeditConfig] | None = None,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> DcmeditOutputs:
    """
    Edit DICOM file in-place.
    
    Note that this command simply replaces the existing values without modifying
    the DICOM structure in any way. Replacement text will be truncated if it is
    too long to fit inside the existing tag.
    
    WARNING: this command will modify existing data! It is recommended to run
    this command on a copy of the original data set to avoid loss of data.
    
    References:
    
    .
    
    Author: MRTrix3 Developers
    
    URL: https://www.mrtrix.org/
    
    Args:
        file: the DICOM file to be edited.
        anonymise: remove any identifiable information, by replacing the\
            following tags:\
            - any tag with Value Representation PN will be replaced with\
            'anonymous'\
            - tag (0010,0030) PatientBirthDate will be replaced with an empty\
            string\
            WARNING: there is no guarantee that this command will remove all\
            identiable information, since such information may be contained in\
            any number of private vendor-specific tags. You will need to\
            double-check the results independently if you need to ensure\
            anonymity.
        id_: replace all ID tags with string supplied. This consists of tags\
            (0010, 0020) PatientID and (0010, 1000) OtherPatientIDs.
        tag: replace specific tag.
        info: display information messages.
        quiet: do not display information messages or progress status;\
            alternatively, this can be achieved by setting the MRTRIX_QUIET\
            environment variable to a non-empty string.
        debug: display debugging messages.
        force: force overwrite of output files (caution: using the same file as\
            input and output might cause unexpected behaviour).
        nthreads: use this number of threads in multi-threaded applications\
            (set to 0 to disable multi-threading).
        config: temporarily set the value of an MRtrix config file entry.
        help_: display this information page and exit.
        version: display version information and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `DcmeditOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(DCMEDIT_METADATA)
    cargs = []
    cargs.append("dcmedit")
    if anonymise:
        cargs.append("-anonymise")
    if id_ is not None:
        cargs.extend([
            "-id",
            id_
        ])
    if tag is not None:
        cargs.extend([a for c in [s.run(execution) for s in tag] for a in c])
    if info:
        cargs.append("-info")
    if quiet:
        cargs.append("-quiet")
    if debug:
        cargs.append("-debug")
    if force:
        cargs.append("-force")
    if nthreads is not None:
        cargs.extend([
            "-nthreads",
            str(nthreads)
        ])
    if config is not None:
        cargs.extend([a for c in [s.run(execution) for s in config] for a in c])
    if help_:
        cargs.append("-help")
    if version:
        cargs.append("-version")
    cargs.append(execution.input_file(file))
    ret = DcmeditOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "DCMEDIT_METADATA",
    "DcmeditConfig",
    "DcmeditOutputs",
    "DcmeditTag",
    "dcmedit",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SUMA_CHANGE_SPEC_METADATA = Metadata(
    id="4bf222ffae950010f81275acc0be3c92fdd2d01c.boutiques",
    name="suma_change_spec",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class SumaChangeSpecOutputs(typing.NamedTuple):
    """
    Output object returned when calling `suma_change_spec(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_spec: OutputPathType | None
    """New Spec file"""
    backup_spec: OutputPathType
    """Backup of the original Spec file"""


def suma_change_spec(
    input_: InputPathType,
    state: str,
    domainparent: str | None = None,
    output: str | None = None,
    remove: bool = False,
    anatomical: bool = False,
    runner: Runner | None = None,
) -> SumaChangeSpecOutputs:
    """
    This program changes SUMA's surface specification (Spec) files.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_: SUMA Spec file to change.
        state: State within the Spec file to change.
        domainparent: New Domain Parent for the state within the Spec file.
        output: Name to which the new Spec file will be temporarily written.
        remove: Remove the automatically created backup.
        anatomical: Add 'Anatomical = Y' to the selected SurfaceState.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SumaChangeSpecOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SUMA_CHANGE_SPEC_METADATA)
    cargs = []
    cargs.append("suma_change_spec")
    cargs.append(execution.input_file(input_))
    cargs.append(state)
    if domainparent is not None:
        cargs.append(domainparent)
    if output is not None:
        cargs.append(output)
    if remove:
        cargs.append("-remove")
    if anatomical:
        cargs.append("-anatomical")
    ret = SumaChangeSpecOutputs(
        root=execution.output_file("."),
        output_spec=execution.output_file(output) if (output is not None) else None,
        backup_spec=execution.output_file(pathlib.Path(input_).name + ".bkp"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SUMA_CHANGE_SPEC_METADATA",
    "SumaChangeSpecOutputs",
    "suma_change_spec",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_ADD_TEMPLATE_METADATA = Metadata(
    id="cad5f1397d4979ef787014fa2412a1f0a10cfe8b.boutiques",
    name="mris_add_template",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisAddTemplateOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_add_template(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    placeholder_output: OutputPathType
    """No outputs available as the tool has been removed."""


def mris_add_template(
    runner: Runner | None = None,
) -> MrisAddTemplateOutputs:
    """
    This tool has been removed from the current version of FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisAddTemplateOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_ADD_TEMPLATE_METADATA)
    cargs = []
    cargs.append("mris_add_template")
    ret = MrisAddTemplateOutputs(
        root=execution.output_file("."),
        placeholder_output=execution.output_file("[PLACEHOLDER_OUTPUT]"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_ADD_TEMPLATE_METADATA",
    "MrisAddTemplateOutputs",
    "mris_add_template",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_KRUSKAL_WALLIS_METADATA = Metadata(
    id="d8f52138ea0ac2f25d27a21c1fd03e57b216b428.boutiques",
    name="3dKruskalWallis",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dKruskalWallisOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_kruskal_wallis(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outfile_prefix: OutputPathType
    """Output file containing Kruskal-Wallis statistics"""


def v_3d_kruskal_wallis(
    levels: int,
    datasets: list[str],
    output: str,
    workmem: int | None = None,
    voxel: int | None = None,
    runner: Runner | None = None,
) -> V3dKruskalWallisOutputs:
    """
    This program performs nonparametric Kruskal-Wallis test for comparison of
    multiple treatments.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        levels: Number of treatments.
        datasets: Data set for treatment #1 through to treatment #s. Specify\
            sub-brick if more than one present.
        output: Kruskal-Wallis statistics are written to file prefixname.
        workmem: Number of megabytes of RAM to use for statistical workspace.
        voxel: Screen output for voxel # num.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dKruskalWallisOutputs`).
    """
    if not (2 <= levels): 
        raise ValueError(f"'levels' must be greater than 2 <= x but was {levels}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_KRUSKAL_WALLIS_METADATA)
    cargs = []
    cargs.append("3dKruskalWallis")
    cargs.extend([
        "-levels",
        str(levels)
    ])
    cargs.extend([
        "-dset",
        *datasets
    ])
    if workmem is not None:
        cargs.extend([
            "-workmem",
            str(workmem)
        ])
    if voxel is not None:
        cargs.extend([
            "-voxel",
            str(voxel)
        ])
    cargs.extend([
        "-out",
        output
    ])
    ret = V3dKruskalWallisOutputs(
        root=execution.output_file("."),
        outfile_prefix=execution.output_file(output + "+tlrc"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dKruskalWallisOutputs",
    "V_3D_KRUSKAL_WALLIS_METADATA",
    "v_3d_kruskal_wallis",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_LABEL_MODE_METADATA = Metadata(
    id="1fe77c6bd59d224a85a54c2c3c93d4c52345517b.boutiques",
    name="mris_label_mode",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisLabelModeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_label_mode(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mris_label_mode(
    input_curv_file: InputPathType,
    hemi: str,
    surface: str,
    subject: list[str],
    output_curv_file: str,
    summary_statistics: bool = False,
    statistics_cond: str | None = None,
    output_directory: str | None = None,
    runner: Runner | None = None,
) -> MrisLabelModeOutputs:
    """
    This program will add a template into an average surface.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_curv_file: Input curvature file.
        hemi: Hemisphere.
        surface: Surface name.
        subject: Subject name(s).
        output_curv_file: Output curvature file.
        summary_statistics: Generate summary statistics.
        statistics_cond: Condition number for summary statistics.
        output_directory: Override the last subject as the output surface.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisLabelModeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_LABEL_MODE_METADATA)
    cargs = []
    cargs.append("mris_label_mode")
    cargs.append(execution.input_file(input_curv_file))
    cargs.append(hemi)
    cargs.append(surface)
    cargs.extend(subject)
    cargs.append(output_curv_file)
    if summary_statistics:
        cargs.append("-s")
    if statistics_cond is not None:
        cargs.append(statistics_cond)
    if output_directory is not None:
        cargs.extend([
            "-o",
            output_directory
        ])
    ret = MrisLabelModeOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_LABEL_MODE_METADATA",
    "MrisLabelModeOutputs",
    "mris_label_mode",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_AUTOBOX_METADATA = Metadata(
    id="614b8e391ea136b04b4fe49d62f798c0eada766e.boutiques",
    name="3dAutobox",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dAutoboxOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_autobox(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v_3d_autobox(
    input_: InputPathType,
    prefix: str | None = None,
    alt_input: InputPathType | None = None,
    noclust: bool = False,
    extent: bool = False,
    extent_ijk: bool = False,
    extent_ijk_to_file: str | None = None,
    extent_ijk_midslice: bool = False,
    extent_ijkord: bool = False,
    extent_ijkord_to_file: str | None = None,
    extent_xyz_to_file: str | None = None,
    extent_xyz_midslice: bool = False,
    npad: float | None = None,
    npad_safety_on: bool = False,
    runner: Runner | None = None,
) -> V3dAutoboxOutputs:
    """
    Computes size of a box that fits around the volume. Can also be used to crop the
    volume to that box.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_: Input dataset.
        prefix: Crop the input dataset to the size of the box, and write an\
            output dataset with PREFIX for the name. If not used, no new volume is\
            written out.
        alt_input: An alternate way to specify the input dataset.
        noclust: Don't do any clustering to find the box. Any non-zero voxel\
            will be preserved in the cropped volume.
        extent: Write to standard out the spatial extent of the box.
        extent_ijk: Write out the 6 auto bbox ijk slice numbers to screen: imin\
            imax jmin jmax kmin kmax.
        extent_ijk_to_file: Write out the 6 auto bbox ijk slice numbers to a\
            simple-formatted text file FF: imin imax jmin jmax kmin kmax.
        extent_ijk_midslice: Write out the 3 ijk midslices of the autobox to\
            the screen: imid jmid kmid.
        extent_ijkord: Write out the 6 auto bbox ijk slice numbers to screen in\
            a particular order and format. Useful for scripting.
        extent_ijkord_to_file: Write out the 6 auto bbox ijk slice numbers to a\
            file in a particular order and format. Useful for 3dcalc expressions.
        extent_xyz_to_file: Write out the 6 auto bbox xyz coordinates to a\
            simple-formatted text file GG: xmin xmax ymin ymax zmin zmax.
        extent_xyz_midslice: Write out the 3 xyz midslices of the autobox to\
            the screen: xmid ymid zmid.
        npad: Number of extra voxels to pad on each side of box.
        npad_safety_on: Constrain npad-ded extents to be within dataset.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dAutoboxOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_AUTOBOX_METADATA)
    cargs = []
    cargs.append("3dAutobox")
    cargs.append(execution.input_file(input_))
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if alt_input is not None:
        cargs.extend([
            "-input",
            execution.input_file(alt_input)
        ])
    if noclust:
        cargs.append("-noclust")
    if extent:
        cargs.append("-extent")
    if extent_ijk:
        cargs.append("-extent_ijk")
    if extent_ijk_to_file is not None:
        cargs.extend([
            "-extent_ijk_to_file",
            extent_ijk_to_file
        ])
    if extent_ijk_midslice:
        cargs.append("-extent_ijk_midslice")
    if extent_ijkord:
        cargs.append("-extent_ijkord")
    if extent_ijkord_to_file is not None:
        cargs.extend([
            "-extent_ijkord_to_file",
            extent_ijkord_to_file
        ])
    if extent_xyz_to_file is not None:
        cargs.extend([
            "-extent_xyz_to_file",
            extent_xyz_to_file
        ])
    if extent_xyz_midslice:
        cargs.append("-extent_xyz_midslice")
    if npad is not None:
        cargs.extend([
            "-npad",
            str(npad)
        ])
    if npad_safety_on:
        cargs.append("-npad_safety_on")
    ret = V3dAutoboxOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dAutoboxOutputs",
    "V_3D_AUTOBOX_METADATA",
    "v_3d_autobox",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_1D_APAR2MAT_METADATA = Metadata(
    id="ca46e845c2aeb2bfc0d1ca66f53ca7adef2d7e64.boutiques",
    name="1dApar2mat",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V1dApar2matOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_1d_apar2mat(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v_1d_apar2mat(
    x_shift: float,
    y_shift: float,
    z_shift: float,
    z_angle: float,
    x_angle: float,
    y_angle: float,
    x_scale: float,
    y_scale: float,
    z_scale: float,
    y_x_shear: float,
    z_x_shear: float,
    z_y_shear: float,
    runner: Runner | None = None,
) -> V1dApar2matOutputs:
    """
    Computes the affine transformation matrix from the set of 3dAllineate
    parameters.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        x_shift: x-shift in mm.
        y_shift: y-shift in mm.
        z_shift: z-shift in mm.
        z_angle: z-angle (roll) in degrees.
        x_angle: x-angle (pitch) in degrees.
        y_angle: y-angle (yaw) in degrees.
        x_scale: x-scale factor in [0.10,10.0].
        y_scale: y-scale factor in [0.10,10.0].
        z_scale: z-scale factor in [0.10,10.0].
        y_x_shear: y/x-shear factor in [-0.3333,0.3333].
        z_x_shear: z/x-shear factor in [-0.3333,0.3333].
        z_y_shear: z/y-shear factor in [-0.3333,0.3333].
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V1dApar2matOutputs`).
    """
    if not (0.1 <= x_scale <= 10.0): 
        raise ValueError(f"'x_scale' must be between 0.1 <= x <= 10.0 but was {x_scale}")
    if not (0.1 <= y_scale <= 10.0): 
        raise ValueError(f"'y_scale' must be between 0.1 <= x <= 10.0 but was {y_scale}")
    if not (0.1 <= z_scale <= 10.0): 
        raise ValueError(f"'z_scale' must be between 0.1 <= x <= 10.0 but was {z_scale}")
    if not (-0.3333 <= y_x_shear <= 0.3333): 
        raise ValueError(f"'y_x_shear' must be between -0.3333 <= x <= 0.3333 but was {y_x_shear}")
    if not (-0.3333 <= z_x_shear <= 0.3333): 
        raise ValueError(f"'z_x_shear' must be between -0.3333 <= x <= 0.3333 but was {z_x_shear}")
    if not (-0.3333 <= z_y_shear <= 0.3333): 
        raise ValueError(f"'z_y_shear' must be between -0.3333 <= x <= 0.3333 but was {z_y_shear}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_1D_APAR2MAT_METADATA)
    cargs = []
    cargs.append("1dApar2mat")
    cargs.append(str(x_shift))
    cargs.append(str(y_shift))
    cargs.append(str(z_shift))
    cargs.append(str(z_angle))
    cargs.append(str(x_angle))
    cargs.append(str(y_angle))
    cargs.append(str(x_scale))
    cargs.append(str(y_scale))
    cargs.append(str(z_scale))
    cargs.append(str(y_x_shear))
    cargs.append(str(z_x_shear))
    cargs.append(str(z_y_shear))
    ret = V1dApar2matOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V1dApar2matOutputs",
    "V_1D_APAR2MAT_METADATA",
    "v_1d_apar2mat",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__ALIGN_PARTIAL_OBLIQUE_METADATA = Metadata(
    id="8266c2389908e7353d0356e57b5059a88cdc6548.boutiques",
    name="@align_partial_oblique",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VAlignPartialObliqueOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__align_partial_oblique(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    aligned_output: OutputPathType
    """Aligned partial coverage T1 weighted dataset"""


def v__align_partial_oblique(
    base: InputPathType,
    input_: InputPathType,
    suffix: str | None = None,
    keep_tmp: bool = False,
    clean: bool = False,
    dxyz: float | None = None,
    dx: float | None = None,
    dy: float | None = None,
    dz: float | None = None,
    runner: Runner | None = None,
) -> VAlignPartialObliqueOutputs:
    """
    A script to align a full coverage T1 weighted non-oblique dataset to match a
    partial coverage T1 weighted non-oblique dataset. Alignment is done with a
    rotation and shift (6 parameters) transform only.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        base: Reference anatomical full coverage volume.
        input_: Partial coverage T1 weighted non-oblique dataset.
        suffix: Output dataset name is formed by adding SUF to the prefix of\
            the base dataset. The default suffix is _alnd_PartialCoverageObliqueT1.
        keep_tmp: Keep temporary files.
        clean: Clean all temp files, likely left from -keep_tmp option then\
            exit.
        dxyz: Cubic voxel size of output dataset in TLRC space Default MM is 1.
        dx: Size of voxel in the x direction (Right-Left). Default is 1mm.
        dy: Size of voxel in the y direction (Anterior-Posterior). Default is\
            1mm.
        dz: Size of voxel in the z direction (Inferior-Superior). Default is\
            1mm.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VAlignPartialObliqueOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__ALIGN_PARTIAL_OBLIQUE_METADATA)
    cargs = []
    cargs.append("@align_partial_oblique")
    cargs.extend([
        "-base",
        execution.input_file(base)
    ])
    cargs.extend([
        "-input",
        execution.input_file(input_)
    ])
    if suffix is not None:
        cargs.extend([
            "-suffix",
            suffix
        ])
    if keep_tmp:
        cargs.append("-keep_tmp")
    if clean:
        cargs.append("-clean")
    if dxyz is not None:
        cargs.extend([
            "-dxyz",
            str(dxyz)
        ])
    if dx is not None:
        cargs.extend([
            "-dx",
            str(dx)
        ])
    if dy is not None:
        cargs.extend([
            "-dy",
            str(dy)
        ])
    if dz is not None:
        cargs.extend([
            "-dz",
            str(dz)
        ])
    ret = VAlignPartialObliqueOutputs(
        root=execution.output_file("."),
        aligned_output=execution.output_file(pathlib.Path(base).name + "_alnd_" + pathlib.Path(input_).name + ".nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VAlignPartialObliqueOutputs",
    "V__ALIGN_PARTIAL_OBLIQUE_METADATA",
    "v__align_partial_oblique",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_NORMALIZE_TP2_METADATA = Metadata(
    id="aee73f5df022fe02e7fc4d5e4771e952936204f3.boutiques",
    name="mri_normalize_tp2",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriNormalizeTp2Outputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_normalize_tp2(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_normalized_vol: OutputPathType
    """The resulting normalized volume"""


def mri_normalize_tp2(
    input_vol: InputPathType,
    normalized_vol: str,
    t1_volume: InputPathType | None = None,
    mask1: InputPathType | None = None,
    mask2: InputPathType | None = None,
    threshold: float | None = None,
    ctrl: InputPathType | None = None,
    xform: InputPathType | None = None,
    invert_flag: bool = False,
    lta_src: InputPathType | None = None,
    lta_dst: InputPathType | None = None,
    runner: Runner | None = None,
) -> MriNormalizeTp2Outputs:
    """
    Normalize the input volume using control points of tp1 to help normalize tp2.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_vol: Input volume to be normalized.
        normalized_vol: Output normalized volume.
        t1_volume: T1 volume for tp1 where normalization is applied.
        mask1: Brain mask for tp1, mapped to tp2 via the xform.
        mask2: Brain mask for tp2, mapped to tp1 via the inverse xform.
        threshold: Threshold for background (default = 1.0).
        ctrl: Control point volume for tp1.
        xform: LTA transform that aligns tp1 to tp2.
        invert_flag: Reversely apply -xform.
        lta_src: Source volume for -xform if not available from the xform file.
        lta_dst: Target volume for -xform if not available from the xform file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriNormalizeTp2Outputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_NORMALIZE_TP2_METADATA)
    cargs = []
    cargs.append("mri_normalize_tp2")
    cargs.append(execution.input_file(input_vol))
    cargs.append(normalized_vol)
    if t1_volume is not None:
        cargs.extend([
            "-T1",
            execution.input_file(t1_volume)
        ])
    if mask1 is not None:
        cargs.extend([
            "-mask1",
            execution.input_file(mask1)
        ])
    if mask2 is not None:
        cargs.extend([
            "-mask2",
            execution.input_file(mask2)
        ])
    if threshold is not None:
        cargs.extend([
            "-threshold",
            str(threshold)
        ])
    if ctrl is not None:
        cargs.extend([
            "-ctrl",
            execution.input_file(ctrl)
        ])
    if xform is not None:
        cargs.extend([
            "-xform",
            execution.input_file(xform)
        ])
    if invert_flag:
        cargs.append("-invert")
    if lta_src is not None:
        cargs.extend([
            "-lta_src",
            execution.input_file(lta_src)
        ])
    if lta_dst is not None:
        cargs.extend([
            "-lta_dst",
            execution.input_file(lta_dst)
        ])
    ret = MriNormalizeTp2Outputs(
        root=execution.output_file("."),
        output_normalized_vol=execution.output_file(normalized_vol),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_NORMALIZE_TP2_METADATA",
    "MriNormalizeTp2Outputs",
    "mri_normalize_tp2",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3DFIM__METADATA = Metadata(
    id="bc809f4b3edfb691248a034084e93881b2cf1fd0.boutiques",
    name="3dfim+",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dfimOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3dfim_(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outfile_tlrc_head: OutputPathType | None
    """Output bucket dataset containing fit parameters, in TLRC space."""
    outfile_tlrc_brk: OutputPathType | None
    """Output bucket dataset containing fit parameters, in TLRC space."""
    outfile_orig_head: OutputPathType | None
    """Output bucket dataset containing fit parameters, in original space."""
    outfile_orig_brk: OutputPathType | None
    """Output bucket dataset containing fit parameters, in original space."""


def v_3dfim_(
    infile: InputPathType,
    ideal_file: InputPathType,
    input1dfile: InputPathType | None = None,
    maskfile: InputPathType | None = None,
    first_image: float | None = None,
    last_image: float | None = None,
    baseline_polynomial: float | None = None,
    threshold: float | None = None,
    cdisp_value: float | None = None,
    ort_file: InputPathType | None = None,
    output_params: list[str] | None = None,
    output_bucket: str | None = None,
    runner: Runner | None = None,
) -> V3dfimOutputs:
    """
    Program to calculate the cross-correlation of an ideal reference waveform with
    the measured FMRI time series for each voxel.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        infile: Filename of input 3d+time dataset.
        ideal_file: Input ideal time series file name. Can be used multiple\
            times.
        input1dfile: Filename of single (fMRI) .1D time series.
        maskfile: Filename of 3d mask dataset.
        first_image: Number of first dataset image to use in the\
            cross-correlation procedure (default = 0).
        last_image: Number of last dataset image to use in the\
            cross-correlation procedure (default = last).
        baseline_polynomial: Degree of polynomial corresponding to the baseline\
            model (default: 1). Use -1 for no baseline model.
        threshold: FIM internal mask threshold value (0 <= p <= 1) to get rid\
            of low intensity voxels (default: 0.0999).
        cdisp_value: Write (to screen) results for voxels whose correlation\
            stat. > cval (0 <= cval <= 1; default: disabled).
        ort_file: Input ort time series file name. Can be used multiple times.
        output_params: Output the specified parameter. Can be used multiple\
            times. Possible values are: 'Fit Coef', 'Best Index', '% Change',\
            'Baseline', 'Correlation', '% From Ave', 'Average', '% From Top',\
            'Topline', 'Sigma Resid', 'All', 'Spearman CC', 'Quadrant CC'.
        output_bucket: Create one AFNI 'bucket' dataset containing the\
            parameters of interest, as specified by the '-out' commands. The output\
            'bucket' dataset is written to a file with the prefix name bprefix.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dfimOutputs`).
    """
    if threshold is not None and not (0 <= threshold <= 1): 
        raise ValueError(f"'threshold' must be between 0 <= x <= 1 but was {threshold}")
    if cdisp_value is not None and not (0 <= cdisp_value <= 1): 
        raise ValueError(f"'cdisp_value' must be between 0 <= x <= 1 but was {cdisp_value}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3DFIM__METADATA)
    cargs = []
    cargs.append("3dfim+")
    cargs.append(execution.input_file(infile))
    if input1dfile is not None:
        cargs.extend([
            "-input1D",
            execution.input_file(input1dfile)
        ])
    if maskfile is not None:
        cargs.extend([
            "-mask",
            execution.input_file(maskfile)
        ])
    if first_image is not None:
        cargs.extend([
            "-nfirst",
            str(first_image)
        ])
    if last_image is not None:
        cargs.extend([
            "-nlast",
            str(last_image)
        ])
    if baseline_polynomial is not None:
        cargs.extend([
            "-polort",
            str(baseline_polynomial)
        ])
    if threshold is not None:
        cargs.extend([
            "-fim_thr",
            str(threshold)
        ])
    if cdisp_value is not None:
        cargs.extend([
            "-cdisp",
            str(cdisp_value)
        ])
    if ort_file is not None:
        cargs.extend([
            "-ort_file",
            execution.input_file(ort_file)
        ])
    cargs.extend([
        "-ideal_file",
        execution.input_file(ideal_file)
    ])
    if output_params is not None:
        cargs.extend([
            "-out",
            *output_params
        ])
    if output_bucket is not None:
        cargs.extend([
            "-bucket",
            output_bucket
        ])
    ret = V3dfimOutputs(
        root=execution.output_file("."),
        outfile_tlrc_head=execution.output_file(output_bucket + "+tlrc.HEAD") if (output_bucket is not None) else None,
        outfile_tlrc_brk=execution.output_file(output_bucket + "+tlrc.BRIK") if (output_bucket is not None) else None,
        outfile_orig_head=execution.output_file(output_bucket + "+orig.HEAD") if (output_bucket is not None) else None,
        outfile_orig_brk=execution.output_file(output_bucket + "+orig.BRIK") if (output_bucket is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dfimOutputs",
    "V_3DFIM__METADATA",
    "v_3dfim_",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

REREGISTER_SUBJECT_MIXED_METADATA = Metadata(
    id="0d4b2b8c11d9a393c8ab3a72de3e1875d4b1135b.boutiques",
    name="reregister_subject_mixed",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class ReregisterSubjectMixedOutputs(typing.NamedTuple):
    """
    Output object returned when calling `reregister_subject_mixed(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    control_points: OutputPathType
    """Transformed control points"""
    intensity_normalized: OutputPathType
    """Intensity normalized output"""
    log_file: OutputPathType
    """Log file for talairach processing"""


def reregister_subject_mixed(
    input_volume: InputPathType,
    output_directory: str,
    threads: float | None = 1,
    runner: Runner | None = None,
) -> ReregisterSubjectMixedOutputs:
    """
    Tool for re-registering a subject's MRI volumes using Freesurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_volume: Input volume file path.
        output_directory: Output directory for transformed control points and\
            intensity normalized files.
        threads: Number of threads available to mri_em_register for OpenMP.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ReregisterSubjectMixedOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(REREGISTER_SUBJECT_MIXED_METADATA)
    cargs = []
    cargs.append("reregister_subject_mixed")
    cargs.append(execution.input_file(input_volume))
    cargs.append(output_directory)
    if threads is not None:
        cargs.append(str(threads))
    ret = ReregisterSubjectMixedOutputs(
        root=execution.output_file("."),
        control_points=execution.output_file(output_directory + "/mri/fsamples"),
        intensity_normalized=execution.output_file(output_directory + "/mri/norm"),
        log_file=execution.output_file("talairach.log"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "REREGISTER_SUBJECT_MIXED_METADATA",
    "ReregisterSubjectMixedOutputs",
    "reregister_subject_mixed",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_DISTANCE_TO_LABEL_METADATA = Metadata(
    id="0538a932ce0052cc0bb4e77e20e1d20d65106c51.boutiques",
    name="mris_distance_to_label",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisDistanceToLabelOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_distance_to_label(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mris_distance_to_label(
    hemisphere: str,
    subject_1: str,
    runner: Runner | None = None,
) -> MrisDistanceToLabelOutputs:
    """
    A tool for measuring the distance between vertices on a surface and a labeled
    region.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        hemisphere: Hemisphere to process (e.g., 'lh' for left hemisphere or\
            'rh' for right hemisphere).
        subject_1: Subject identifier or path to the subject directory.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisDistanceToLabelOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_DISTANCE_TO_LABEL_METADATA)
    cargs = []
    cargs.append("mris_distance_to_label")
    cargs.append(hemisphere)
    cargs.append(subject_1)
    ret = MrisDistanceToLabelOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_DISTANCE_TO_LABEL_METADATA",
    "MrisDistanceToLabelOutputs",
    "mris_distance_to_label",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_SURF_MASK_METADATA = Metadata(
    id="55dc0c4e1d7ff3d126a0dfcd22e6d94d6ee4130c.boutiques",
    name="3dSurfMask",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dSurfMaskOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_surf_mask(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_mask: OutputPathType
    """Main output mask dataset."""
    distance_dataset: OutputPathType
    """Dataset reflecting voxel shortest distances to the surface."""


def v_3d_surf_mask(
    surface_type: str,
    surface_file: InputPathType,
    prefix: str,
    grid_parent: InputPathType,
    fill_method: str | None = None,
    surface_volume: InputPathType | None = None,
    mask_only: bool = False,
    flip_orientation: bool = False,
    no_distance: bool = False,
    runner: Runner | None = None,
) -> V3dSurfMaskOutputs:
    """
    Creates volumetric datasets marking voxels based on their location relative to a
    surface.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        surface_type: Specify input surface.
        surface_file: Specify input surface filename.
        prefix: Prefix of output dataset.
        grid_parent: Specifies the grid for the output volume.
        fill_method: Fill method: SLOW or FAST (default: FAST).
        surface_volume: Specify the surface volume.
        mask_only: Produce an output dataset where voxels are 1 inside the\
            surface and 0 outside.
        flip_orientation: Flip triangle winding of surface mesh.
        no_distance: Do not compute the distances, just the mask from the first\
            step.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dSurfMaskOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_SURF_MASK_METADATA)
    cargs = []
    cargs.append("3dSurfMask")
    cargs.append(surface_type)
    cargs.append(execution.input_file(surface_file))
    cargs.append(prefix)
    cargs.append(execution.input_file(grid_parent))
    if fill_method is not None:
        cargs.extend([
            "-fill_method",
            fill_method
        ])
    if surface_volume is not None:
        cargs.extend([
            "-sv",
            execution.input_file(surface_volume)
        ])
    if mask_only:
        cargs.append("-mask_only")
    if flip_orientation:
        cargs.append("-flip_orientation")
    if no_distance:
        cargs.append("-no_dist")
    ret = V3dSurfMaskOutputs(
        root=execution.output_file("."),
        output_mask=execution.output_file(prefix + ".m+orig.BRIK"),
        distance_dataset=execution.output_file(prefix + ".d+orig.BRIK"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dSurfMaskOutputs",
    "V_3D_SURF_MASK_METADATA",
    "v_3d_surf_mask",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SEGMENT_SUBJECT_T2_AUTO_ESTIMATE_ALVEUS_ML_METADATA = Metadata(
    id="8a6a12eb1eae4567d49625f69155e84f68466b3c.boutiques",
    name="segmentSubjectT2_autoEstimateAlveusML",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class SegmentSubjectT2AutoEstimateAlveusMlOutputs(typing.NamedTuple):
    """
    Output object returned when calling `segment_subject_t2_auto_estimate_alveus_ml(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def segment_subject_t2_auto_estimate_alveus_ml(
    runner: Runner | None = None,
) -> SegmentSubjectT2AutoEstimateAlveusMlOutputs:
    """
    A Freesurfer tool to segment T2 subjects with automatic alveus ML estimation.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SegmentSubjectT2AutoEstimateAlveusMlOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SEGMENT_SUBJECT_T2_AUTO_ESTIMATE_ALVEUS_ML_METADATA)
    cargs = []
    cargs.append("segmentSubjectT2_autoEstimateAlveusML")
    ret = SegmentSubjectT2AutoEstimateAlveusMlOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SEGMENT_SUBJECT_T2_AUTO_ESTIMATE_ALVEUS_ML_METADATA",
    "SegmentSubjectT2AutoEstimateAlveusMlOutputs",
    "segment_subject_t2_auto_estimate_alveus_ml",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SFIM_METADATA = Metadata(
    id="62032460073e6537145dc05bebbde2400a1cbdbc.boutiques",
    name="sfim",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class SfimOutputs(typing.NamedTuple):
    """
    Output object returned when calling `sfim(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_files: OutputPathType | None
    """Output image file for interval 'i' with task state name."""


def sfim(
    sfint_file: str | None = None,
    baseline_state: str | None = None,
    local_base_option: bool = False,
    output_prefix: str | None = None,
    runner: Runner | None = None,
) -> SfimOutputs:
    """
    Stepwise Functional IMages.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        sfint_file: Filename which contains the interval definitions. Default\
            is 'sfint'. Example: '3*# 5*rest 4*A 5*rest 4*B 5*rest 4*A 5*rest'.
        baseline_state: Task state name to use as the baseline. Default is\
            'rest'.
        local_base_option: Flag to indicate if each non-base task state\
            interval should have the mean of the two nearest base intervals\
            subtracted instead of the grand mean of all the base task intervals.
        output_prefix: Prefix for output image filenames for all states. The\
            i'th interval with task state name 'fred' will be written to file\
            'pname.fred.i'. Default is 'sfim'.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SfimOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SFIM_METADATA)
    cargs = []
    cargs.append("sfim")
    if sfint_file is not None:
        cargs.extend([
            "-sfint",
            sfint_file
        ])
    if baseline_state is not None:
        cargs.extend([
            "-base",
            baseline_state
        ])
    if local_base_option:
        cargs.append("-localbase")
    if output_prefix is not None:
        cargs.extend([
            "-prefix",
            output_prefix
        ])
    cargs.append("[INPUT_FILES...]")
    ret = SfimOutputs(
        root=execution.output_file("."),
        output_files=execution.output_file(output_prefix + ".*.i") if (output_prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SFIM_METADATA",
    "SfimOutputs",
    "sfim",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

TAL_COMPARE_METADATA = Metadata(
    id="bd1f3a28d4c8c84481961fd651bc3318b4c7368c.boutiques",
    name="tal_compare",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class TalCompareOutputs(typing.NamedTuple):
    """
    Output object returned when calling `tal_compare(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    comparison_results: OutputPathType
    """Comparison results output file."""


def tal_compare(
    ref_file: InputPathType,
    moving_file: InputPathType,
    output_file: str,
    verbose: bool = False,
    runner: Runner | None = None,
) -> TalCompareOutputs:
    """
    Tool for comparing TAL databases.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        ref_file: Reference TAL database file.
        moving_file: Moving TAL database file to compare against the reference.
        output_file: Output file to store comparison results.
        verbose: Enable verbose output.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `TalCompareOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(TAL_COMPARE_METADATA)
    cargs = []
    cargs.append("tal_compare")
    cargs.append(execution.input_file(ref_file))
    cargs.append(execution.input_file(moving_file))
    cargs.append(output_file)
    if verbose:
        cargs.append("-v")
    ret = TalCompareOutputs(
        root=execution.output_file("."),
        comparison_results=execution.output_file(output_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "TAL_COMPARE_METADATA",
    "TalCompareOutputs",
    "tal_compare",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_THICKNESS_METADATA = Metadata(
    id="1f70790c09e2a07e9627e797f2437c49106bcce2.boutiques",
    name="mris_thickness",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisThicknessOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_thickness(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_thickness_file: OutputPathType
    """Output curvature file containing thickness measurements."""


def mris_thickness(
    subject_name: str,
    hemi: str,
    thickness_file: str,
    max_threshold: float | None = None,
    fill_holes: list[str] | None = None,
    thickness_from_seg: list[str] | None = None,
    vector: bool = False,
    runner: Runner | None = None,
) -> MrisThicknessOutputs:
    """
    Measures the thickness of the cortical surface.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject_name: The subject name for processing.
        hemi: The hemisphere to process (e.g., lh or rh).
        thickness_file: Output file for thickness measurements.
        max_threshold: Use a maximum threshold for thickness (default is 5mm).
        fill_holes: Fill in thickness in holes in the cortex label using\
            fsaverage cortex label.
        thickness_from_seg: Compute thickness from segmentation. Requires the\
            following parameters: surf label, seg.mgz, dmaxmm, ddeltamm, and\
            output.mgz.
        vector: Compute the thickness using a variationally derived vector\
            field.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisThicknessOutputs`).
    """
    if fill_holes is not None and (len(fill_holes) != 2): 
        raise ValueError(f"Length of 'fill_holes' must be 2 but was {len(fill_holes)}")
    if thickness_from_seg is not None and (len(thickness_from_seg) != 5): 
        raise ValueError(f"Length of 'thickness_from_seg' must be 5 but was {len(thickness_from_seg)}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_THICKNESS_METADATA)
    cargs = []
    cargs.append("mris_thickness")
    cargs.append(subject_name)
    cargs.append(hemi)
    cargs.append(thickness_file)
    if max_threshold is not None:
        cargs.extend([
            "-max",
            str(max_threshold)
        ])
    if fill_holes is not None:
        cargs.extend([
            "-fill_holes",
            *fill_holes
        ])
    if thickness_from_seg is not None:
        cargs.extend([
            "-thickness-from-seg",
            *thickness_from_seg
        ])
    if vector:
        cargs.append("-vector")
    ret = MrisThicknessOutputs(
        root=execution.output_file("."),
        output_thickness_file=execution.output_file(thickness_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_THICKNESS_METADATA",
    "MrisThicknessOutputs",
    "mris_thickness",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSPALM_METADATA = Metadata(
    id="99a4d5403d2183af602919ad014d4db78cf3675b.boutiques",
    name="fspalm",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class FspalmOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fspalm(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def fspalm(
    glmdir: str,
    cft: float,
    cwp: float,
    onetail: bool = False,
    twotail: bool = False,
    name: str | None = None,
    iters: float | None = None,
    monly: bool = False,
    pponly: bool = False,
    octave: bool = False,
    centroid: bool = False,
    v_2spaces: bool = False,
    v_3spaces: bool = False,
    pargs: str | None = None,
    runner: Runner | None = None,
) -> FspalmOutputs:
    """
    Prepares and analyzes the output of mri_glmfit for Permutation Analysis of
    Linear Models (PALM) to correct for multiple comparisons.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        glmdir: The mri_glmfit directory to prepare.
        cft: Voxel-wise cluster forming threshold (CFT), -log10(p).
        cwp: Clusterwise p-value threshold.
        onetail: Perform a one-tailed test.
        twotail: Perform a two-tailed test. NOTE: changes CFT.
        name: Name of palm subdirectory (default="palm").
        iters: Number of iterations.
        monly: Only create matlab file, do not run.
        pponly: Only perform post-processing.
        octave: Run with octave, not matlab.
        centroid: Add --centroid flag to mri_surfcluster post-processing.
        v_2spaces: Bonferroni-correct for 2 spaces.
        v_3spaces: Bonferroni-correct for 3 spaces.
        pargs: Supply additional args to be passed to the palm function.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FspalmOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSPALM_METADATA)
    cargs = []
    cargs.append("fspalm")
    cargs.extend([
        "--glmdir",
        glmdir
    ])
    cargs.extend([
        "--cft",
        str(cft)
    ])
    cargs.extend([
        "--cwp",
        str(cwp)
    ])
    if onetail:
        cargs.append("--onetail")
    if twotail:
        cargs.append("--twotail")
    if name is not None:
        cargs.extend([
            "--name",
            name
        ])
    if iters is not None:
        cargs.extend([
            "--iters",
            str(iters)
        ])
    if monly:
        cargs.append("--monly")
    if pponly:
        cargs.append("--pponly")
    if octave:
        cargs.append("--octave")
    if centroid:
        cargs.append("--centroid")
    if v_2spaces:
        cargs.append("--2spaces")
    if v_3spaces:
        cargs.append("--3spaces")
    if pargs is not None:
        cargs.extend([
            "--pargs",
            pargs
        ])
    ret = FspalmOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSPALM_METADATA",
    "FspalmOutputs",
    "fspalm",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

STATTABLEDIFF_METADATA = Metadata(
    id="1700b5a4affda702434ee9916d498190f06c350c.boutiques",
    name="stattablediff",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class StattablediffOutputs(typing.NamedTuple):
    """
    Output object returned when calling `stattablediff(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_diff_table: OutputPathType
    """Generated table of differences"""


def stattablediff(
    t1: InputPathType,
    t2: InputPathType,
    output: str,
    percent_diff: bool = False,
    percent_diff_t1: bool = False,
    percent_diff_t2: bool = False,
    multiply: float | None = None,
    divide: float | None = None,
    common: bool = False,
    remove_exvivo: bool = False,
    diff_subjects: bool = False,
    noreplace53: bool = False,
    runner: Runner | None = None,
) -> StattablediffOutputs:
    """
    Creates a table of the differences between two stats tables.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        t1: Input table 1 (output of asegstats2table or aparcstats2table).
        t2: Input table 2 (output of asegstats2table or aparcstats2table).
        output: Output file for the table of differences.
        percent_diff: Compute percent difference with respect to mean of tables.
        percent_diff_t1: Compute percent difference with respect to table 1.
        percent_diff_t2: Compute percent difference with respect to table 2.
        multiply: Multiply by mulval.
        divide: Divide by divval.
        common: Compute difference on common segments (may reorder).
        remove_exvivo: Remove the string '_exvivo' from the column header.
        diff_subjects: Compare subjects with different names.
        noreplace53: Do not replace 5.3 structure names with later names.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `StattablediffOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(STATTABLEDIFF_METADATA)
    cargs = []
    cargs.append("stattablediff")
    cargs.append(execution.input_file(t1))
    cargs.append(execution.input_file(t2))
    cargs.append(output)
    if percent_diff:
        cargs.append("--percent")
    if percent_diff_t1:
        cargs.append("--percent1")
    if percent_diff_t2:
        cargs.append("--percent2")
    if multiply is not None:
        cargs.extend([
            "--mul",
            str(multiply)
        ])
    if divide is not None:
        cargs.extend([
            "--div",
            str(divide)
        ])
    if common:
        cargs.append("--common")
    if remove_exvivo:
        cargs.append("--rm-exvivo")
    if diff_subjects:
        cargs.append("--diff-subjs")
    if noreplace53:
        cargs.append("--noreplace53")
    ret = StattablediffOutputs(
        root=execution.output_file("."),
        output_diff_table=execution.output_file(output),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "STATTABLEDIFF_METADATA",
    "StattablediffOutputs",
    "stattablediff",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_ANOVA2_METADATA = Metadata(
    id="ebf600e872cacd3686c204e18def40bac83877e7.boutiques",
    name="3dANOVA2",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dAnova2Outputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_anova2(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_ftr: OutputPathType | None
    """F-statistic for treatment effect output file"""
    output_fa: OutputPathType | None
    """F-statistic for factor A effect output file"""
    output_fb: OutputPathType | None
    """F-statistic for factor B effect output file"""
    output_fab: OutputPathType | None
    """F-statistic for interaction output file"""
    output_amean: OutputPathType | None
    """Estimate mean of factor A level output file"""
    output_bmean: OutputPathType | None
    """Estimate mean of factor B level output file"""
    output_xmean: OutputPathType | None
    """Estimate mean of cell at level i of factor A and level j of factor B
    output file"""
    output_adiff: OutputPathType | None
    """Difference between levels i and j of factor A output file"""
    output_bdiff: OutputPathType | None
    """Difference between levels i and j of factor B output file"""
    output_xdiff: OutputPathType | None
    """Difference between cell mean at A=i, B=j and cell mean at A=k, B=l output
    file"""
    output_acontr: OutputPathType | None
    """Contrast in factor A levels output file"""
    output_bcontr: OutputPathType | None
    """Contrast in factor B levels output file"""
    output_xcontr: OutputPathType | None
    """Contrast in cell means output file"""
    output_bucket: OutputPathType | None
    """Create one AFNI 'bucket' dataset file"""


def v_3d_anova2(
    type_: int,
    alevels: int,
    blevels: int,
    dataset: list[str] | None = None,
    voxel: int | None = None,
    diskspace: bool = False,
    mask: InputPathType | None = None,
    ftr: str | None = None,
    fa: str | None = None,
    fb: str | None = None,
    fab: str | None = None,
    amean: str | None = None,
    bmean: str | None = None,
    xmean: str | None = None,
    adiff: str | None = None,
    bdiff: str | None = None,
    xdiff: str | None = None,
    acontr: str | None = None,
    bcontr: str | None = None,
    xcontr: str | None = None,
    bucket: str | None = None,
    old_method: bool = False,
    ok: bool = False,
    assume_sph: bool = False,
    runner: Runner | None = None,
) -> V3dAnova2Outputs:
    """
    This program performs a two-factor Analysis of Variance (ANOVA) on 3D datasets.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        type_: Type of ANOVA model to be used: 1=fixed, 2=random, 3=mixed.
        alevels: Number of levels of factor A.
        blevels: Number of levels of factor B.
        dataset: Data set for levels of factor A and factor B.
        voxel: Screen output for voxel number.
        diskspace: Print out disk space required for program execution.
        mask: Use sub-brick #0 of dataset 'mset' to define which voxels to\
            process.
        ftr: F-statistic for treatment effect.
        fa: F-statistic for factor A effect.
        fb: F-statistic for factor B effect.
        fab: F-statistic for interaction.
        amean: Estimate mean of factor A level.
        bmean: Estimate mean of factor B level.
        xmean: Estimate mean of cell at level i of factor A and level j of\
            factor B.
        adiff: Difference between levels i and j of factor A.
        bdiff: Difference between levels i and j of factor B.
        xdiff: Difference between cell mean at A=i, B=j and cell mean at A=k,\
            B=l.
        acontr: Contrast in factor A levels.
        bcontr: Contrast in factor B levels.
        xcontr: Contrast in cell means.
        bucket: Create one AFNI 'bucket' dataset whose sub-bricks are obtained\
            by concatenating the above output files.
        old_method: Request to perform ANOVA using the previous functionality\
            (requires -OK, also).
        ok: Confirm understanding that contrasts that do not sum to zero have\
            inflated t-stats, and contrasts that do sum to zero assume sphericity\
            (to be used with -old_method).
        assume_sph: Assume sphericity (zero-sum contrasts, only). This allows\
            use of the old_method for computing contrasts which sum to zero.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dAnova2Outputs`).
    """
    if not (1 <= type_ <= 3): 
        raise ValueError(f"'type_' must be between 1 <= x <= 3 but was {type_}")
    if dataset is not None and not (1 <= len(dataset)): 
        raise ValueError(f"Length of 'dataset' must be greater than 1 but was {len(dataset)}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_ANOVA2_METADATA)
    cargs = []
    cargs.append("3dANOVA2")
    cargs.extend([
        "-type",
        str(type_)
    ])
    cargs.extend([
        "-alevels",
        str(alevels)
    ])
    cargs.extend([
        "-blevels",
        str(blevels)
    ])
    if dataset is not None:
        cargs.extend([
            "-dset",
            *dataset
        ])
    if voxel is not None:
        cargs.extend([
            "-voxel",
            str(voxel)
        ])
    if diskspace:
        cargs.append("-diskspace")
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    if ftr is not None:
        cargs.extend([
            "-ftr",
            ftr
        ])
    if fa is not None:
        cargs.extend([
            "-fa",
            fa
        ])
    if fb is not None:
        cargs.extend([
            "-fb",
            fb
        ])
    if fab is not None:
        cargs.extend([
            "-fab",
            fab
        ])
    if amean is not None:
        cargs.extend([
            "-amean",
            amean
        ])
    if bmean is not None:
        cargs.extend([
            "-bmean",
            bmean
        ])
    if xmean is not None:
        cargs.extend([
            "-xmean",
            xmean
        ])
    if adiff is not None:
        cargs.extend([
            "-adiff",
            adiff
        ])
    if bdiff is not None:
        cargs.extend([
            "-bdiff",
            bdiff
        ])
    if xdiff is not None:
        cargs.extend([
            "-xdiff",
            xdiff
        ])
    if acontr is not None:
        cargs.extend([
            "-acontr",
            acontr
        ])
    if bcontr is not None:
        cargs.extend([
            "-bcontr",
            bcontr
        ])
    if xcontr is not None:
        cargs.extend([
            "-xcontr",
            xcontr
        ])
    if bucket is not None:
        cargs.extend([
            "-bucket",
            bucket
        ])
    if old_method:
        cargs.append("-old_method")
    if ok:
        cargs.append("-OK")
    if assume_sph:
        cargs.append("-assume_sph")
    ret = V3dAnova2Outputs(
        root=execution.output_file("."),
        output_ftr=execution.output_file(ftr + ".+tlrc") if (ftr is not None) else None,
        output_fa=execution.output_file(fa + ".+tlrc") if (fa is not None) else None,
        output_fb=execution.output_file(fb + ".+tlrc") if (fb is not None) else None,
        output_fab=execution.output_file(fab + ".+tlrc") if (fab is not None) else None,
        output_amean=execution.output_file(amean + ".+tlrc") if (amean is not None) else None,
        output_bmean=execution.output_file(bmean + ".+tlrc") if (bmean is not None) else None,
        output_xmean=execution.output_file(xmean + ".+tlrc") if (xmean is not None) else None,
        output_adiff=execution.output_file(adiff + ".+tlrc") if (adiff is not None) else None,
        output_bdiff=execution.output_file(bdiff + ".+tlrc") if (bdiff is not None) else None,
        output_xdiff=execution.output_file(xdiff + ".+tlrc") if (xdiff is not None) else None,
        output_acontr=execution.output_file(acontr + ".+tlrc") if (acontr is not None) else None,
        output_bcontr=execution.output_file(bcontr + ".+tlrc") if (bcontr is not None) else None,
        output_xcontr=execution.output_file(xcontr + ".+tlrc") if (xcontr is not None) else None,
        output_bucket=execution.output_file(bucket + ".+tlrc") if (bucket is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dAnova2Outputs",
    "V_3D_ANOVA2_METADATA",
    "v_3d_anova2",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MINC2SEQINFO_METADATA = Metadata(
    id="30fbf462a54b5ca1f7c6f0f4e71bda9dbde0712d.boutiques",
    name="minc2seqinfo",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class Minc2seqinfoOutputs(typing.NamedTuple):
    """
    Output object returned when calling `minc2seqinfo(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_seqinfofile: OutputPathType
    """File containing the extracted sequence information."""


def minc2seqinfo(
    mincfile: InputPathType,
    seqinfofile: str,
    runner: Runner | None = None,
) -> Minc2seqinfoOutputs:
    """
    Tool for extracting sequence information from MINC files.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        mincfile: Input MINC file from which to extract sequence information.
        seqinfofile: Output file where the sequence information will be stored.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Minc2seqinfoOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MINC2SEQINFO_METADATA)
    cargs = []
    cargs.append("minc2seqinfo")
    cargs.append(execution.input_file(mincfile))
    cargs.append(seqinfofile)
    ret = Minc2seqinfoOutputs(
        root=execution.output_file("."),
        out_seqinfofile=execution.output_file(seqinfofile),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MINC2SEQINFO_METADATA",
    "Minc2seqinfoOutputs",
    "minc2seqinfo",
]
